/* runner.c generated by valac 0.35.5, the Vala compiler
 * generated from runner.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>


#define GAMES_TYPE_RUNNER (games_runner_get_type ())
#define GAMES_RUNNER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_RUNNER, GamesRunner))
#define GAMES_IS_RUNNER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_RUNNER))
#define GAMES_RUNNER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_RUNNER, GamesRunnerIface))

typedef struct _GamesRunner GamesRunner;
typedef struct _GamesRunnerIface GamesRunnerIface;

#define GAMES_TYPE_MEDIA_SET (games_media_set_get_type ())
#define GAMES_MEDIA_SET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_MEDIA_SET, GamesMediaSet))
#define GAMES_MEDIA_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_MEDIA_SET, GamesMediaSetClass))
#define GAMES_IS_MEDIA_SET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_MEDIA_SET))
#define GAMES_IS_MEDIA_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_MEDIA_SET))
#define GAMES_MEDIA_SET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_MEDIA_SET, GamesMediaSetClass))

typedef struct _GamesMediaSet GamesMediaSet;
typedef struct _GamesMediaSetClass GamesMediaSetClass;
enum  {
	GAMES_RUNNER_STOPPED_SIGNAL,
	GAMES_RUNNER_LAST_SIGNAL
};
static guint games_runner_signals[GAMES_RUNNER_LAST_SIGNAL] = {0};

struct _GamesRunnerIface {
	GTypeInterface parent_iface;
	gboolean (*check_is_valid) (GamesRunner* self, gchar* * error_message, GError** error);
	GtkWidget* (*get_display) (GamesRunner* self);
	void (*start) (GamesRunner* self, GError** error);
	void (*resume) (GamesRunner* self, GError** error);
	void (*pause) (GamesRunner* self);
	void (*stop) (GamesRunner* self);
	gboolean (*get_can_fullscreen) (GamesRunner* self);
	gboolean (*get_can_quit_safely) (GamesRunner* self);
	gboolean (*get_can_resume) (GamesRunner* self);
	GamesMediaSet* (*get_media_set) (GamesRunner* self);
};



GType games_media_set_get_type (void) G_GNUC_CONST;
GType games_runner_get_type (void) G_GNUC_CONST;
gboolean games_runner_check_is_valid (GamesRunner* self, gchar* * error_message, GError** error);
GtkWidget* games_runner_get_display (GamesRunner* self);
void games_runner_start (GamesRunner* self, GError** error);
void games_runner_resume (GamesRunner* self, GError** error);
void games_runner_pause (GamesRunner* self);
void games_runner_stop (GamesRunner* self);
gboolean games_runner_get_can_fullscreen (GamesRunner* self);
gboolean games_runner_get_can_quit_safely (GamesRunner* self);
gboolean games_runner_get_can_resume (GamesRunner* self);
GamesMediaSet* games_runner_get_media_set (GamesRunner* self);


gboolean games_runner_check_is_valid (GamesRunner* self, gchar* * error_message, GError** error) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GAMES_RUNNER_GET_INTERFACE (self)->check_is_valid (self, error_message, error);
}


GtkWidget* games_runner_get_display (GamesRunner* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GAMES_RUNNER_GET_INTERFACE (self)->get_display (self);
}


void games_runner_start (GamesRunner* self, GError** error) {
	g_return_if_fail (self != NULL);
	GAMES_RUNNER_GET_INTERFACE (self)->start (self, error);
}


void games_runner_resume (GamesRunner* self, GError** error) {
	g_return_if_fail (self != NULL);
	GAMES_RUNNER_GET_INTERFACE (self)->resume (self, error);
}


void games_runner_pause (GamesRunner* self) {
	g_return_if_fail (self != NULL);
	GAMES_RUNNER_GET_INTERFACE (self)->pause (self);
}


void games_runner_stop (GamesRunner* self) {
	g_return_if_fail (self != NULL);
	GAMES_RUNNER_GET_INTERFACE (self)->stop (self);
}


gboolean games_runner_get_can_fullscreen (GamesRunner* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GAMES_RUNNER_GET_INTERFACE (self)->get_can_fullscreen (self);
}


gboolean games_runner_get_can_quit_safely (GamesRunner* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GAMES_RUNNER_GET_INTERFACE (self)->get_can_quit_safely (self);
}


gboolean games_runner_get_can_resume (GamesRunner* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GAMES_RUNNER_GET_INTERFACE (self)->get_can_resume (self);
}


GamesMediaSet* games_runner_get_media_set (GamesRunner* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GAMES_RUNNER_GET_INTERFACE (self)->get_media_set (self);
}


static void games_runner_base_init (GamesRunnerIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_boolean ("can-fullscreen", "can-fullscreen", "can-fullscreen", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_boolean ("can-quit-safely", "can-quit-safely", "can-quit-safely", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_boolean ("can-resume", "can-resume", "can-resume", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("media-set", "media-set", "media-set", GAMES_TYPE_MEDIA_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		games_runner_signals[GAMES_RUNNER_STOPPED_SIGNAL] = g_signal_new ("stopped", GAMES_TYPE_RUNNER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	}
}


GType games_runner_get_type (void) {
	static volatile gsize games_runner_type_id__volatile = 0;
	if (g_once_init_enter (&games_runner_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesRunnerIface), (GBaseInitFunc) games_runner_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType games_runner_type_id;
		games_runner_type_id = g_type_register_static (G_TYPE_INTERFACE, "GamesRunner", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (games_runner_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&games_runner_type_id__volatile, games_runner_type_id);
	}
	return games_runner_type_id__volatile;
}



