/* dummy-cover.c generated by valac 0.35.5, the Vala compiler
 * generated from dummy-cover.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>


#define GAMES_TYPE_COVER (games_cover_get_type ())
#define GAMES_COVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_COVER, GamesCover))
#define GAMES_IS_COVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_COVER))
#define GAMES_COVER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_COVER, GamesCoverIface))

typedef struct _GamesCover GamesCover;
typedef struct _GamesCoverIface GamesCoverIface;

#define GAMES_TYPE_DUMMY_COVER (games_dummy_cover_get_type ())
#define GAMES_DUMMY_COVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_DUMMY_COVER, GamesDummyCover))
#define GAMES_DUMMY_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_DUMMY_COVER, GamesDummyCoverClass))
#define GAMES_IS_DUMMY_COVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_DUMMY_COVER))
#define GAMES_IS_DUMMY_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_DUMMY_COVER))
#define GAMES_DUMMY_COVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_DUMMY_COVER, GamesDummyCoverClass))

typedef struct _GamesDummyCover GamesDummyCover;
typedef struct _GamesDummyCoverClass GamesDummyCoverClass;
typedef struct _GamesDummyCoverPrivate GamesDummyCoverPrivate;

struct _GamesCoverIface {
	GTypeInterface parent_iface;
	GIcon* (*get_cover) (GamesCover* self);
};

struct _GamesDummyCover {
	GObject parent_instance;
	GamesDummyCoverPrivate * priv;
};

struct _GamesDummyCoverClass {
	GObjectClass parent_class;
};


static gpointer games_dummy_cover_parent_class = NULL;
static GamesCoverIface * games_dummy_cover_games_cover_parent_iface = NULL;

GType games_cover_get_type (void) G_GNUC_CONST;
GType games_dummy_cover_get_type (void) G_GNUC_CONST;
enum  {
	GAMES_DUMMY_COVER_DUMMY_PROPERTY
};
static GIcon* games_dummy_cover_real_get_cover (GamesCover* base);
GamesDummyCover* games_dummy_cover_new (void);
GamesDummyCover* games_dummy_cover_construct (GType object_type);


static GIcon* games_dummy_cover_real_get_cover (GamesCover* base) {
	GamesDummyCover * self;
	GIcon* result = NULL;
	self = (GamesDummyCover*) base;
	result = NULL;
	return result;
}


GamesDummyCover* games_dummy_cover_construct (GType object_type) {
	GamesDummyCover * self = NULL;
	self = (GamesDummyCover*) g_object_new (object_type, NULL);
	return self;
}


GamesDummyCover* games_dummy_cover_new (void) {
	return games_dummy_cover_construct (GAMES_TYPE_DUMMY_COVER);
}


static void games_dummy_cover_class_init (GamesDummyCoverClass * klass) {
	games_dummy_cover_parent_class = g_type_class_peek_parent (klass);
}


static void games_dummy_cover_games_cover_interface_init (GamesCoverIface * iface) {
	games_dummy_cover_games_cover_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_cover = (GIcon* (*) (GamesCover *)) games_dummy_cover_real_get_cover;
}


static void games_dummy_cover_instance_init (GamesDummyCover * self) {
}


GType games_dummy_cover_get_type (void) {
	static volatile gsize games_dummy_cover_type_id__volatile = 0;
	if (g_once_init_enter (&games_dummy_cover_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesDummyCoverClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) games_dummy_cover_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GamesDummyCover), 0, (GInstanceInitFunc) games_dummy_cover_instance_init, NULL };
		static const GInterfaceInfo games_cover_info = { (GInterfaceInitFunc) games_dummy_cover_games_cover_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType games_dummy_cover_type_id;
		games_dummy_cover_type_id = g_type_register_static (G_TYPE_OBJECT, "GamesDummyCover", &g_define_type_info, 0);
		g_type_add_interface_static (games_dummy_cover_type_id, GAMES_TYPE_COVER, &games_cover_info);
		g_once_init_leave (&games_dummy_cover_type_id__volatile, games_dummy_cover_type_id);
	}
	return games_dummy_cover_type_id__volatile;
}



