/* standard-gamepad-button.c generated by valac 0.35.5, the Vala compiler
 * generated from standard-gamepad-button.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>


#define GAMES_TYPE_STANDARD_GAMEPAD_BUTTON (games_standard_gamepad_button_get_type ())

typedef enum  {
	GAMES_STANDARD_GAMEPAD_BUTTON_UNKNOWN,
	GAMES_STANDARD_GAMEPAD_BUTTON_A,
	GAMES_STANDARD_GAMEPAD_BUTTON_B,
	GAMES_STANDARD_GAMEPAD_BUTTON_X,
	GAMES_STANDARD_GAMEPAD_BUTTON_Y,
	GAMES_STANDARD_GAMEPAD_BUTTON_SHOULDER_L,
	GAMES_STANDARD_GAMEPAD_BUTTON_SHOULDER_R,
	GAMES_STANDARD_GAMEPAD_BUTTON_TRIGGER_L,
	GAMES_STANDARD_GAMEPAD_BUTTON_TRIGGER_R,
	GAMES_STANDARD_GAMEPAD_BUTTON_SELECT,
	GAMES_STANDARD_GAMEPAD_BUTTON_START,
	GAMES_STANDARD_GAMEPAD_BUTTON_STICK_L,
	GAMES_STANDARD_GAMEPAD_BUTTON_STICK_R,
	GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_UP,
	GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_DOWN,
	GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_LEFT,
	GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_RIGHT,
	GAMES_STANDARD_GAMEPAD_BUTTON_HOME
} GamesStandardGamepadButton;



GType games_standard_gamepad_button_get_type (void) G_GNUC_CONST;


GType games_standard_gamepad_button_get_type (void) {
	static volatile gsize games_standard_gamepad_button_type_id__volatile = 0;
	if (g_once_init_enter (&games_standard_gamepad_button_type_id__volatile)) {
		static const GEnumValue values[] = {{GAMES_STANDARD_GAMEPAD_BUTTON_UNKNOWN, "GAMES_STANDARD_GAMEPAD_BUTTON_UNKNOWN", "unknown"}, {GAMES_STANDARD_GAMEPAD_BUTTON_A, "GAMES_STANDARD_GAMEPAD_BUTTON_A", "a"}, {GAMES_STANDARD_GAMEPAD_BUTTON_B, "GAMES_STANDARD_GAMEPAD_BUTTON_B", "b"}, {GAMES_STANDARD_GAMEPAD_BUTTON_X, "GAMES_STANDARD_GAMEPAD_BUTTON_X", "x"}, {GAMES_STANDARD_GAMEPAD_BUTTON_Y, "GAMES_STANDARD_GAMEPAD_BUTTON_Y", "y"}, {GAMES_STANDARD_GAMEPAD_BUTTON_SHOULDER_L, "GAMES_STANDARD_GAMEPAD_BUTTON_SHOULDER_L", "shoulder-l"}, {GAMES_STANDARD_GAMEPAD_BUTTON_SHOULDER_R, "GAMES_STANDARD_GAMEPAD_BUTTON_SHOULDER_R", "shoulder-r"}, {GAMES_STANDARD_GAMEPAD_BUTTON_TRIGGER_L, "GAMES_STANDARD_GAMEPAD_BUTTON_TRIGGER_L", "trigger-l"}, {GAMES_STANDARD_GAMEPAD_BUTTON_TRIGGER_R, "GAMES_STANDARD_GAMEPAD_BUTTON_TRIGGER_R", "trigger-r"}, {GAMES_STANDARD_GAMEPAD_BUTTON_SELECT, "GAMES_STANDARD_GAMEPAD_BUTTON_SELECT", "select"}, {GAMES_STANDARD_GAMEPAD_BUTTON_START, "GAMES_STANDARD_GAMEPAD_BUTTON_START", "start"}, {GAMES_STANDARD_GAMEPAD_BUTTON_STICK_L, "GAMES_STANDARD_GAMEPAD_BUTTON_STICK_L", "stick-l"}, {GAMES_STANDARD_GAMEPAD_BUTTON_STICK_R, "GAMES_STANDARD_GAMEPAD_BUTTON_STICK_R", "stick-r"}, {GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_UP, "GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_UP", "dpad-up"}, {GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_DOWN, "GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_DOWN", "dpad-down"}, {GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_LEFT, "GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_LEFT", "dpad-left"}, {GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_RIGHT, "GAMES_STANDARD_GAMEPAD_BUTTON_DPAD_RIGHT", "dpad-right"}, {GAMES_STANDARD_GAMEPAD_BUTTON_HOME, "GAMES_STANDARD_GAMEPAD_BUTTON_HOME", "home"}, {0, NULL, NULL}};
		GType games_standard_gamepad_button_type_id;
		games_standard_gamepad_button_type_id = g_enum_register_static ("GamesStandardGamepadButton", values);
		g_once_init_leave (&games_standard_gamepad_button_type_id__volatile, games_standard_gamepad_button_type_id);
	}
	return games_standard_gamepad_button_type_id__volatile;
}



