/* ui-state.c generated by valac 0.35.5, the Vala compiler
 * generated from ui-state.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>


#define GAMES_TYPE_UI_STATE (games_ui_state_get_type ())

typedef enum  {
	GAMES_UI_STATE_COLLECTION,
	GAMES_UI_STATE_DISPLAY
} GamesUiState;



GType games_ui_state_get_type (void) G_GNUC_CONST;


GType games_ui_state_get_type (void) {
	static volatile gsize games_ui_state_type_id__volatile = 0;
	if (g_once_init_enter (&games_ui_state_type_id__volatile)) {
		static const GEnumValue values[] = {{GAMES_UI_STATE_COLLECTION, "GAMES_UI_STATE_COLLECTION", "collection"}, {GAMES_UI_STATE_DISPLAY, "GAMES_UI_STATE_DISPLAY", "display"}, {0, NULL, NULL}};
		GType games_ui_state_type_id;
		games_ui_state_type_id = g_enum_register_static ("GamesUiState", values);
		g_once_init_leave (&games_ui_state_type_id__volatile, games_ui_state_type_id);
	}
	return games_ui_state_type_id__volatile;
}



