/* cover.c generated by valac 0.35.5, the Vala compiler
 * generated from cover.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>


#define GAMES_TYPE_COVER (games_cover_get_type ())
#define GAMES_COVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_COVER, GamesCover))
#define GAMES_IS_COVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_COVER))
#define GAMES_COVER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_COVER, GamesCoverIface))

typedef struct _GamesCover GamesCover;
typedef struct _GamesCoverIface GamesCoverIface;
enum  {
	GAMES_COVER_CHANGED_SIGNAL,
	GAMES_COVER_LAST_SIGNAL
};
static guint games_cover_signals[GAMES_COVER_LAST_SIGNAL] = {0};

struct _GamesCoverIface {
	GTypeInterface parent_iface;
	GIcon* (*get_cover) (GamesCover* self);
};



GType games_cover_get_type (void) G_GNUC_CONST;
GIcon* games_cover_get_cover (GamesCover* self);


GIcon* games_cover_get_cover (GamesCover* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GAMES_COVER_GET_INTERFACE (self)->get_cover (self);
}


static void games_cover_base_init (GamesCoverIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		games_cover_signals[GAMES_COVER_CHANGED_SIGNAL] = g_signal_new ("changed", GAMES_TYPE_COVER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	}
}


GType games_cover_get_type (void) {
	static volatile gsize games_cover_type_id__volatile = 0;
	if (g_once_init_enter (&games_cover_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesCoverIface), (GBaseInitFunc) games_cover_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType games_cover_type_id;
		games_cover_type_id = g_type_register_static (G_TYPE_INTERFACE, "GamesCover", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (games_cover_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&games_cover_type_id__volatile, games_cover_type_id);
	}
	return games_cover_type_id__volatile;
}



