// This file is part of GNOME Games. License: GPLv3

namespace Games.Credits {
	private const string[] AUTHORS = {
		"Adrien Plazas <kekun.plazas@laposte.net>",
		"Sebastien Nicouleaud <sebn@users.noreply.github.com>",
	};

	private const string[] ARTISTS = {
		"Adrien Plazas <kekun.plazas@laposte.net>",
	};

	private const string[] DOCUMENTERS = null;
}
