/* config.c generated by valac 0.35.5, the Vala compiler
 * generated from config.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>







