/* mega-drive-system.c generated by valac 0.35.5, the Vala compiler
 * generated from mega-drive-system.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>


#define GAMES_TYPE_MEGA_DRIVE_SYSTEM (games_mega_drive_system_get_type ())

typedef enum  {
	GAMES_MEGA_DRIVE_SYSTEM_INVALID,
	GAMES_MEGA_DRIVE_SYSTEM_MEGA_DRIVE,
	GAMES_MEGA_DRIVE_SYSTEM_32X,
	GAMES_MEGA_DRIVE_SYSTEM_PICO,
	GAMES_MEGA_DRIVE_SYSTEM_MEGA_CD,
	GAMES_MEGA_DRIVE_SYSTEM_MEGA_CD_32X
} GamesMegaDriveSystem;



GType games_mega_drive_system_get_type (void) G_GNUC_CONST;


GType games_mega_drive_system_get_type (void) {
	static volatile gsize games_mega_drive_system_type_id__volatile = 0;
	if (g_once_init_enter (&games_mega_drive_system_type_id__volatile)) {
		static const GEnumValue values[] = {{GAMES_MEGA_DRIVE_SYSTEM_INVALID, "GAMES_MEGA_DRIVE_SYSTEM_INVALID", "invalid"}, {GAMES_MEGA_DRIVE_SYSTEM_MEGA_DRIVE, "GAMES_MEGA_DRIVE_SYSTEM_MEGA_DRIVE", "mega-drive"}, {GAMES_MEGA_DRIVE_SYSTEM_32X, "GAMES_MEGA_DRIVE_SYSTEM_32X", "32x"}, {GAMES_MEGA_DRIVE_SYSTEM_PICO, "GAMES_MEGA_DRIVE_SYSTEM_PICO", "pico"}, {GAMES_MEGA_DRIVE_SYSTEM_MEGA_CD, "GAMES_MEGA_DRIVE_SYSTEM_MEGA_CD", "mega-cd"}, {GAMES_MEGA_DRIVE_SYSTEM_MEGA_CD_32X, "GAMES_MEGA_DRIVE_SYSTEM_MEGA_CD_32X", "mega-cd-32x"}, {0, NULL, NULL}};
		GType games_mega_drive_system_type_id;
		games_mega_drive_system_type_id = g_enum_register_static ("GamesMegaDriveSystem", values);
		g_once_init_leave (&games_mega_drive_system_type_id__volatile, games_mega_drive_system_type_id);
	}
	return games_mega_drive_system_type_id__volatile;
}



