/* standard-gamepad-axis.c generated by valac 0.35.5, the Vala compiler
 * generated from standard-gamepad-axis.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>


#define GAMES_TYPE_STANDARD_GAMEPAD_AXIS (games_standard_gamepad_axis_get_type ())

typedef enum  {
	GAMES_STANDARD_GAMEPAD_AXIS_UNKNOWN,
	GAMES_STANDARD_GAMEPAD_AXIS_LEFT_X,
	GAMES_STANDARD_GAMEPAD_AXIS_LEFT_Y,
	GAMES_STANDARD_GAMEPAD_AXIS_RIGHT_X,
	GAMES_STANDARD_GAMEPAD_AXIS_RIGHT_Y
} GamesStandardGamepadAxis;



GType games_standard_gamepad_axis_get_type (void) G_GNUC_CONST;


GType games_standard_gamepad_axis_get_type (void) {
	static volatile gsize games_standard_gamepad_axis_type_id__volatile = 0;
	if (g_once_init_enter (&games_standard_gamepad_axis_type_id__volatile)) {
		static const GEnumValue values[] = {{GAMES_STANDARD_GAMEPAD_AXIS_UNKNOWN, "GAMES_STANDARD_GAMEPAD_AXIS_UNKNOWN", "unknown"}, {GAMES_STANDARD_GAMEPAD_AXIS_LEFT_X, "GAMES_STANDARD_GAMEPAD_AXIS_LEFT_X", "left-x"}, {GAMES_STANDARD_GAMEPAD_AXIS_LEFT_Y, "GAMES_STANDARD_GAMEPAD_AXIS_LEFT_Y", "left-y"}, {GAMES_STANDARD_GAMEPAD_AXIS_RIGHT_X, "GAMES_STANDARD_GAMEPAD_AXIS_RIGHT_X", "right-x"}, {GAMES_STANDARD_GAMEPAD_AXIS_RIGHT_Y, "GAMES_STANDARD_GAMEPAD_AXIS_RIGHT_Y", "right-y"}, {0, NULL, NULL}};
		GType games_standard_gamepad_axis_type_id;
		games_standard_gamepad_axis_type_id = g_enum_register_static ("GamesStandardGamepadAxis", values);
		g_once_init_leave (&games_standard_gamepad_axis_type_id__volatile, games_standard_gamepad_axis_type_id);
	}
	return games_standard_gamepad_axis_type_id__volatile;
}



