/* mime-type-tracker-query.c generated by valac 0.35.5, the Vala compiler
 * generated from mime-type-tracker-query.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <libtracker-sparql/tracker-sparql.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <gtk/gtk.h>


#define GAMES_TYPE_TRACKER_QUERY (games_tracker_query_get_type ())
#define GAMES_TRACKER_QUERY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_TRACKER_QUERY, GamesTrackerQuery))
#define GAMES_IS_TRACKER_QUERY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_TRACKER_QUERY))
#define GAMES_TRACKER_QUERY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_TRACKER_QUERY, GamesTrackerQueryIface))

typedef struct _GamesTrackerQuery GamesTrackerQuery;
typedef struct _GamesTrackerQueryIface GamesTrackerQueryIface;

#define GAMES_TYPE_GAME (games_game_get_type ())
#define GAMES_GAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GAME, GamesGame))
#define GAMES_IS_GAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GAME))
#define GAMES_GAME_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_GAME, GamesGameIface))

typedef struct _GamesGame GamesGame;
typedef struct _GamesGameIface GamesGameIface;

#define GAMES_TYPE_ICON (games_icon_get_type ())
#define GAMES_ICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_ICON, GamesIcon))
#define GAMES_IS_ICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_ICON))
#define GAMES_ICON_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_ICON, GamesIconIface))

typedef struct _GamesIcon GamesIcon;
typedef struct _GamesIconIface GamesIconIface;

#define GAMES_TYPE_COVER (games_cover_get_type ())
#define GAMES_COVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_COVER, GamesCover))
#define GAMES_IS_COVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_COVER))
#define GAMES_COVER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_COVER, GamesCoverIface))

typedef struct _GamesCover GamesCover;
typedef struct _GamesCoverIface GamesCoverIface;

#define GAMES_TYPE_RUNNER (games_runner_get_type ())
#define GAMES_RUNNER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_RUNNER, GamesRunner))
#define GAMES_IS_RUNNER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_RUNNER))
#define GAMES_RUNNER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_RUNNER, GamesRunnerIface))

typedef struct _GamesRunner GamesRunner;
typedef struct _GamesRunnerIface GamesRunnerIface;

#define GAMES_TYPE_MEDIA_SET (games_media_set_get_type ())
#define GAMES_MEDIA_SET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_MEDIA_SET, GamesMediaSet))
#define GAMES_MEDIA_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_MEDIA_SET, GamesMediaSetClass))
#define GAMES_IS_MEDIA_SET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_MEDIA_SET))
#define GAMES_IS_MEDIA_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_MEDIA_SET))
#define GAMES_MEDIA_SET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_MEDIA_SET, GamesMediaSetClass))

typedef struct _GamesMediaSet GamesMediaSet;
typedef struct _GamesMediaSetClass GamesMediaSetClass;

#define GAMES_TYPE_MIME_TYPE_TRACKER_QUERY (games_mime_type_tracker_query_get_type ())
#define GAMES_MIME_TYPE_TRACKER_QUERY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_MIME_TYPE_TRACKER_QUERY, GamesMimeTypeTrackerQuery))
#define GAMES_MIME_TYPE_TRACKER_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_MIME_TYPE_TRACKER_QUERY, GamesMimeTypeTrackerQueryClass))
#define GAMES_IS_MIME_TYPE_TRACKER_QUERY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_MIME_TYPE_TRACKER_QUERY))
#define GAMES_IS_MIME_TYPE_TRACKER_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_MIME_TYPE_TRACKER_QUERY))
#define GAMES_MIME_TYPE_TRACKER_QUERY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_MIME_TYPE_TRACKER_QUERY, GamesMimeTypeTrackerQueryClass))

typedef struct _GamesMimeTypeTrackerQuery GamesMimeTypeTrackerQuery;
typedef struct _GamesMimeTypeTrackerQueryClass GamesMimeTypeTrackerQueryClass;
typedef struct _GamesMimeTypeTrackerQueryPrivate GamesMimeTypeTrackerQueryPrivate;

#define GAMES_TYPE_URI_GAME_FACTORY (games_uri_game_factory_get_type ())
#define GAMES_URI_GAME_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_URI_GAME_FACTORY, GamesUriGameFactory))
#define GAMES_IS_URI_GAME_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_URI_GAME_FACTORY))
#define GAMES_URI_GAME_FACTORY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_URI_GAME_FACTORY, GamesUriGameFactoryIface))

typedef struct _GamesUriGameFactory GamesUriGameFactory;
typedef struct _GamesUriGameFactoryIface GamesUriGameFactoryIface;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _GamesMimeTypeTrackerQueryForeachGameData GamesMimeTypeTrackerQueryForeachGameData;

struct _GamesIconIface {
	GTypeInterface parent_iface;
	GIcon* (*get_icon) (GamesIcon* self);
};

struct _GamesCoverIface {
	GTypeInterface parent_iface;
	GIcon* (*get_cover) (GamesCover* self);
};

struct _GamesRunnerIface {
	GTypeInterface parent_iface;
	gboolean (*check_is_valid) (GamesRunner* self, gchar* * error_message, GError** error);
	GtkWidget* (*get_display) (GamesRunner* self);
	void (*start) (GamesRunner* self, GError** error);
	void (*resume) (GamesRunner* self, GError** error);
	void (*pause) (GamesRunner* self);
	void (*stop) (GamesRunner* self);
	gboolean (*get_can_fullscreen) (GamesRunner* self);
	gboolean (*get_can_quit_safely) (GamesRunner* self);
	gboolean (*get_can_resume) (GamesRunner* self);
	GamesMediaSet* (*get_media_set) (GamesRunner* self);
};

struct _GamesGameIface {
	GTypeInterface parent_iface;
	GamesIcon* (*get_icon) (GamesGame* self);
	GamesCover* (*get_cover) (GamesGame* self);
	GamesRunner* (*get_runner) (GamesGame* self, GError** error);
	const gchar* (*get_name) (GamesGame* self);
};

typedef void (*GamesGameCallback) (GamesGame* game, void* user_data);
struct _GamesTrackerQueryIface {
	GTypeInterface parent_iface;
	gboolean (*is_cursor_valid) (GamesTrackerQuery* self, TrackerSparqlCursor* cursor);
	gchar* (*get_query) (GamesTrackerQuery* self);
	void (*process_cursor) (GamesTrackerQuery* self, TrackerSparqlCursor* cursor);
	void (*foreach_game) (GamesTrackerQuery* self, GamesGameCallback game_callback, void* game_callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*foreach_game_finish) (GamesTrackerQuery* self, GAsyncResult* _res_);
};

struct _GamesMimeTypeTrackerQuery {
	GObject parent_instance;
	GamesMimeTypeTrackerQueryPrivate * priv;
};

struct _GamesMimeTypeTrackerQueryClass {
	GObjectClass parent_class;
};

struct _GamesUriGameFactoryIface {
	GTypeInterface parent_iface;
	gboolean (*is_uri_valid) (GamesUriGameFactory* self, const gchar* uri);
	void (*add_uri) (GamesUriGameFactory* self, const gchar* uri);
	void (*foreach_game) (GamesUriGameFactory* self, GamesGameCallback game_callback, void* game_callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*foreach_game_finish) (GamesUriGameFactory* self, GAsyncResult* _res_);
};

struct _GamesMimeTypeTrackerQueryPrivate {
	gchar* mime_type;
	GamesUriGameFactory* uri_game_factory;
};

struct _GamesMimeTypeTrackerQueryForeachGameData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	gboolean _task_complete_;
	GamesMimeTypeTrackerQuery* self;
	GamesGameCallback game_callback;
	gpointer game_callback_target;
	GamesUriGameFactory* _tmp0_;
	GamesGameCallback _tmp1_;
	void* _tmp1__target;
};


static gpointer games_mime_type_tracker_query_parent_class = NULL;
static GamesTrackerQueryIface * games_mime_type_tracker_query_games_tracker_query_parent_iface = NULL;

GType games_icon_get_type (void) G_GNUC_CONST;
GType games_cover_get_type (void) G_GNUC_CONST;
GType games_media_set_get_type (void) G_GNUC_CONST;
GType games_runner_get_type (void) G_GNUC_CONST;
GType games_game_get_type (void) G_GNUC_CONST;
GType games_tracker_query_get_type (void) G_GNUC_CONST;
GType games_mime_type_tracker_query_get_type (void) G_GNUC_CONST;
GType games_uri_game_factory_get_type (void) G_GNUC_CONST;
#define GAMES_MIME_TYPE_TRACKER_QUERY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GAMES_TYPE_MIME_TYPE_TRACKER_QUERY, GamesMimeTypeTrackerQueryPrivate))
enum  {
	GAMES_MIME_TYPE_TRACKER_QUERY_DUMMY_PROPERTY
};
GamesMimeTypeTrackerQuery* games_mime_type_tracker_query_new (const gchar* mime_type, GamesUriGameFactory* uri_game_factory);
GamesMimeTypeTrackerQuery* games_mime_type_tracker_query_construct (GType object_type, const gchar* mime_type, GamesUriGameFactory* uri_game_factory);
static gchar* games_mime_type_tracker_query_real_get_query (GamesTrackerQuery* base);
static gboolean games_mime_type_tracker_query_real_is_cursor_valid (GamesTrackerQuery* base, TrackerSparqlCursor* cursor);
gboolean games_uri_game_factory_is_uri_valid (GamesUriGameFactory* self, const gchar* uri);
static void games_mime_type_tracker_query_real_process_cursor (GamesTrackerQuery* base, TrackerSparqlCursor* cursor);
void games_uri_game_factory_add_uri (GamesUriGameFactory* self, const gchar* uri);
static void games_mime_type_tracker_query_real_foreach_game_data_free (gpointer _data);
static void games_mime_type_tracker_query_real_foreach_game (GamesTrackerQuery* base, GamesGameCallback game_callback, void* game_callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean games_mime_type_tracker_query_real_foreach_game_co (GamesMimeTypeTrackerQueryForeachGameData* _data_);
void games_uri_game_factory_foreach_game (GamesUriGameFactory* self, GamesGameCallback game_callback, void* game_callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
void games_uri_game_factory_foreach_game_finish (GamesUriGameFactory* self, GAsyncResult* _res_);
static void games_mime_type_tracker_query_foreach_game_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void games_mime_type_tracker_query_finalize (GObject * obj);


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


GamesMimeTypeTrackerQuery* games_mime_type_tracker_query_construct (GType object_type, const gchar* mime_type, GamesUriGameFactory* uri_game_factory) {
	GamesMimeTypeTrackerQuery * self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	GamesUriGameFactory* _tmp2_;
	GamesUriGameFactory* _tmp3_;
	g_return_val_if_fail (mime_type != NULL, NULL);
	g_return_val_if_fail (uri_game_factory != NULL, NULL);
	self = (GamesMimeTypeTrackerQuery*) g_object_new (object_type, NULL);
	_tmp0_ = mime_type;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->mime_type);
	self->priv->mime_type = _tmp1_;
	_tmp2_ = uri_game_factory;
	_tmp3_ = _g_object_ref0 (_tmp2_);
	_g_object_unref0 (self->priv->uri_game_factory);
	self->priv->uri_game_factory = _tmp3_;
	return self;
}


GamesMimeTypeTrackerQuery* games_mime_type_tracker_query_new (const gchar* mime_type, GamesUriGameFactory* uri_game_factory) {
	return games_mime_type_tracker_query_construct (GAMES_TYPE_MIME_TYPE_TRACKER_QUERY, mime_type, uri_game_factory);
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}


static gchar* games_mime_type_tracker_query_real_get_query (GamesTrackerQuery* base) {
	GamesMimeTypeTrackerQuery * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	self = (GamesMimeTypeTrackerQuery*) base;
	_tmp0_ = self->priv->mime_type;
	_tmp1_ = string_to_string (_tmp0_);
	_tmp2_ = g_strconcat ("SELECT DISTINCT nie:url(?urn) WHERE { ?urn nie:mimeType \"", _tmp1_, "\" . }", NULL);
	result = _tmp2_;
	return result;
}


static gboolean games_mime_type_tracker_query_real_is_cursor_valid (GamesTrackerQuery* base, TrackerSparqlCursor* cursor) {
	GamesMimeTypeTrackerQuery * self;
	gboolean result = FALSE;
	gchar* uri;
	TrackerSparqlCursor* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	GamesUriGameFactory* _tmp3_;
	gboolean _tmp4_;
	self = (GamesMimeTypeTrackerQuery*) base;
	g_return_val_if_fail (cursor != NULL, FALSE);
	_tmp0_ = cursor;
	_tmp1_ = tracker_sparql_cursor_get_string (_tmp0_, 0, NULL);
	_tmp2_ = g_strdup (_tmp1_);
	uri = _tmp2_;
	_tmp3_ = self->priv->uri_game_factory;
	_tmp4_ = games_uri_game_factory_is_uri_valid (_tmp3_, uri);
	result = _tmp4_;
	_g_free0 (uri);
	return result;
}


static void games_mime_type_tracker_query_real_process_cursor (GamesTrackerQuery* base, TrackerSparqlCursor* cursor) {
	GamesMimeTypeTrackerQuery * self;
	gchar* uri;
	TrackerSparqlCursor* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	GamesUriGameFactory* _tmp3_;
	self = (GamesMimeTypeTrackerQuery*) base;
	g_return_if_fail (cursor != NULL);
	_tmp0_ = cursor;
	_tmp1_ = tracker_sparql_cursor_get_string (_tmp0_, 0, NULL);
	_tmp2_ = g_strdup (_tmp1_);
	uri = _tmp2_;
	_tmp3_ = self->priv->uri_game_factory;
	games_uri_game_factory_add_uri (_tmp3_, uri);
	_g_free0 (uri);
}


static void games_mime_type_tracker_query_real_foreach_game_data_free (gpointer _data) {
	GamesMimeTypeTrackerQueryForeachGameData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (GamesMimeTypeTrackerQueryForeachGameData, _data_);
}


static void games_mime_type_tracker_query_real_foreach_game (GamesTrackerQuery* base, GamesGameCallback game_callback, void* game_callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	GamesMimeTypeTrackerQuery * self;
	GamesMimeTypeTrackerQueryForeachGameData* _data_;
	GamesMimeTypeTrackerQuery* _tmp0_;
	GamesGameCallback _tmp1_;
	void* _tmp1__target;
	self = (GamesMimeTypeTrackerQuery*) base;
	_data_ = g_slice_new0 (GamesMimeTypeTrackerQueryForeachGameData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	if (_callback_ == NULL) {
		_data_->_task_complete_ = TRUE;
	}
	g_task_set_task_data (_data_->_async_result, _data_, games_mime_type_tracker_query_real_foreach_game_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = game_callback;
	_tmp1__target = game_callback_target;
	_data_->game_callback = _tmp1_;
	_data_->game_callback_target = _tmp1__target;
	games_mime_type_tracker_query_real_foreach_game_co (_data_);
}


static void games_mime_type_tracker_query_real_foreach_game_finish (GamesTrackerQuery* base, GAsyncResult* _res_) {
	GamesMimeTypeTrackerQueryForeachGameData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
	_data_->_task_complete_ = TRUE;
}


static void games_mime_type_tracker_query_foreach_game_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	GamesMimeTypeTrackerQueryForeachGameData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	_data_->_task_complete_ = TRUE;
	games_mime_type_tracker_query_real_foreach_game_co (_data_);
}


static gboolean games_mime_type_tracker_query_real_foreach_game_co (GamesMimeTypeTrackerQueryForeachGameData* _data_) {
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->uri_game_factory;
	_data_->_tmp1_ = _data_->game_callback;
	_data_->_tmp1__target = _data_->game_callback_target;
	_data_->_state_ = 1;
	games_uri_game_factory_foreach_game (_data_->_tmp0_, _data_->_tmp1_, _data_->_tmp1__target, games_mime_type_tracker_query_foreach_game_ready, _data_);
	return FALSE;
	_state_1:
	games_uri_game_factory_foreach_game_finish (_data_->_tmp0_, _data_->_res_);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (_data_->_task_complete_ != TRUE) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}


static void games_mime_type_tracker_query_class_init (GamesMimeTypeTrackerQueryClass * klass) {
	games_mime_type_tracker_query_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (GamesMimeTypeTrackerQueryPrivate));
	G_OBJECT_CLASS (klass)->finalize = games_mime_type_tracker_query_finalize;
}


static void games_mime_type_tracker_query_games_tracker_query_interface_init (GamesTrackerQueryIface * iface) {
	games_mime_type_tracker_query_games_tracker_query_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_query = (gchar* (*) (GamesTrackerQuery *)) games_mime_type_tracker_query_real_get_query;
	iface->is_cursor_valid = (gboolean (*) (GamesTrackerQuery *, TrackerSparqlCursor*)) games_mime_type_tracker_query_real_is_cursor_valid;
	iface->process_cursor = (void (*) (GamesTrackerQuery *, TrackerSparqlCursor*)) games_mime_type_tracker_query_real_process_cursor;
	iface->foreach_game = (void (*) (GamesTrackerQuery *, GamesGameCallback, void*)) games_mime_type_tracker_query_real_foreach_game;
	iface->foreach_game_finish = games_mime_type_tracker_query_real_foreach_game_finish;
}


static void games_mime_type_tracker_query_instance_init (GamesMimeTypeTrackerQuery * self) {
	self->priv = GAMES_MIME_TYPE_TRACKER_QUERY_GET_PRIVATE (self);
}


static void games_mime_type_tracker_query_finalize (GObject * obj) {
	GamesMimeTypeTrackerQuery * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GAMES_TYPE_MIME_TYPE_TRACKER_QUERY, GamesMimeTypeTrackerQuery);
	_g_free0 (self->priv->mime_type);
	_g_object_unref0 (self->priv->uri_game_factory);
	G_OBJECT_CLASS (games_mime_type_tracker_query_parent_class)->finalize (obj);
}


GType games_mime_type_tracker_query_get_type (void) {
	static volatile gsize games_mime_type_tracker_query_type_id__volatile = 0;
	if (g_once_init_enter (&games_mime_type_tracker_query_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesMimeTypeTrackerQueryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) games_mime_type_tracker_query_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GamesMimeTypeTrackerQuery), 0, (GInstanceInitFunc) games_mime_type_tracker_query_instance_init, NULL };
		static const GInterfaceInfo games_tracker_query_info = { (GInterfaceInitFunc) games_mime_type_tracker_query_games_tracker_query_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType games_mime_type_tracker_query_type_id;
		games_mime_type_tracker_query_type_id = g_type_register_static (G_TYPE_OBJECT, "GamesMimeTypeTrackerQuery", &g_define_type_info, 0);
		g_type_add_interface_static (games_mime_type_tracker_query_type_id, GAMES_TYPE_TRACKER_QUERY, &games_tracker_query_info);
		g_once_init_leave (&games_mime_type_tracker_query_type_id__volatile, games_mime_type_tracker_query_type_id);
	}
	return games_mime_type_tracker_query_type_id__volatile;
}



