/* media-set-error.c generated by valac 0.35.5, the Vala compiler
 * generated from media-set-error.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>


typedef enum  {
	GAMES_MEDIA_SET_ERROR_NOT_A_MEDIA
} GamesMediaSetError;
#define GAMES_MEDIA_SET_ERROR games_media_set_error_quark ()


GQuark games_media_set_error_quark (void);


GQuark games_media_set_error_quark (void) {
	return g_quark_from_static_string ("games_media_set_error-quark");
}



