/* cue-sheet-file-format.c generated by valac 0.35.5, the Vala compiler
 * generated from cue-sheet-file-format.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>


#define GAMES_TYPE_CUE_SHEET_FILE_FORMAT (games_cue_sheet_file_format_get_type ())

typedef enum  {
	GAMES_CUE_SHEET_FILE_FORMAT_INVALID,
	GAMES_CUE_SHEET_FILE_FORMAT_AIFF,
	GAMES_CUE_SHEET_FILE_FORMAT_BINARY,
	GAMES_CUE_SHEET_FILE_FORMAT_MOTOROLA,
	GAMES_CUE_SHEET_FILE_FORMAT_MP3,
	GAMES_CUE_SHEET_FILE_FORMAT_VORBIS,
	GAMES_CUE_SHEET_FILE_FORMAT_WAVE,
	GAMES_CUE_SHEET_FILE_FORMAT_UNKNOWN
} GamesCueSheetFileFormat;



GType games_cue_sheet_file_format_get_type (void) G_GNUC_CONST;
GamesCueSheetFileFormat games_cue_sheet_file_format_parse_string (const gchar* value);


GamesCueSheetFileFormat games_cue_sheet_file_format_parse_string (const gchar* value) {
	GamesCueSheetFileFormat result = 0;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GQuark _tmp3_ = 0U;
	static GQuark _tmp2_label0 = 0;
	static GQuark _tmp2_label1 = 0;
	static GQuark _tmp2_label2 = 0;
	static GQuark _tmp2_label3 = 0;
	static GQuark _tmp2_label4 = 0;
	static GQuark _tmp2_label5 = 0;
	static GQuark _tmp2_label6 = 0;
	_tmp0_ = value;
	_tmp1_ = _tmp0_;
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
	if (_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string ("AIFF")))) {
		switch (0) {
			default:
			{
				result = GAMES_CUE_SHEET_FILE_FORMAT_AIFF;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string ("BINARY")))) {
		switch (0) {
			default:
			{
				result = GAMES_CUE_SHEET_FILE_FORMAT_BINARY;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string ("MOTOROLA")))) {
		switch (0) {
			default:
			{
				result = GAMES_CUE_SHEET_FILE_FORMAT_MOTOROLA;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label3) ? _tmp2_label3 : (_tmp2_label3 = g_quark_from_static_string ("MP3")))) {
		switch (0) {
			default:
			{
				result = GAMES_CUE_SHEET_FILE_FORMAT_MP3;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label4) ? _tmp2_label4 : (_tmp2_label4 = g_quark_from_static_string ("VORBIS")))) {
		switch (0) {
			default:
			{
				result = GAMES_CUE_SHEET_FILE_FORMAT_VORBIS;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label5) ? _tmp2_label5 : (_tmp2_label5 = g_quark_from_static_string ("WAVE")))) {
		switch (0) {
			default:
			{
				result = GAMES_CUE_SHEET_FILE_FORMAT_WAVE;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label6) ? _tmp2_label6 : (_tmp2_label6 = g_quark_from_static_string (NULL)))) {
		switch (0) {
			default:
			{
				result = GAMES_CUE_SHEET_FILE_FORMAT_UNKNOWN;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				result = GAMES_CUE_SHEET_FILE_FORMAT_INVALID;
				return result;
			}
		}
	}
}


GType games_cue_sheet_file_format_get_type (void) {
	static volatile gsize games_cue_sheet_file_format_type_id__volatile = 0;
	if (g_once_init_enter (&games_cue_sheet_file_format_type_id__volatile)) {
		static const GEnumValue values[] = {{GAMES_CUE_SHEET_FILE_FORMAT_INVALID, "GAMES_CUE_SHEET_FILE_FORMAT_INVALID", "invalid"}, {GAMES_CUE_SHEET_FILE_FORMAT_AIFF, "GAMES_CUE_SHEET_FILE_FORMAT_AIFF", "aiff"}, {GAMES_CUE_SHEET_FILE_FORMAT_BINARY, "GAMES_CUE_SHEET_FILE_FORMAT_BINARY", "binary"}, {GAMES_CUE_SHEET_FILE_FORMAT_MOTOROLA, "GAMES_CUE_SHEET_FILE_FORMAT_MOTOROLA", "motorola"}, {GAMES_CUE_SHEET_FILE_FORMAT_MP3, "GAMES_CUE_SHEET_FILE_FORMAT_MP3", "mp3"}, {GAMES_CUE_SHEET_FILE_FORMAT_VORBIS, "GAMES_CUE_SHEET_FILE_FORMAT_VORBIS", "vorbis"}, {GAMES_CUE_SHEET_FILE_FORMAT_WAVE, "GAMES_CUE_SHEET_FILE_FORMAT_WAVE", "wave"}, {GAMES_CUE_SHEET_FILE_FORMAT_UNKNOWN, "GAMES_CUE_SHEET_FILE_FORMAT_UNKNOWN", "unknown"}, {0, NULL, NULL}};
		GType games_cue_sheet_file_format_type_id;
		games_cue_sheet_file_format_type_id = g_enum_register_static ("GamesCueSheetFileFormat", values);
		g_once_init_leave (&games_cue_sheet_file_format_type_id__volatile, games_cue_sheet_file_format_type_id);
	}
	return games_cue_sheet_file_format_type_id__volatile;
}



