/* cue-sheet-error.c generated by valac 0.35.5, the Vala compiler
 * generated from cue-sheet-error.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>


typedef enum  {
	GAMES_CUE_SHEET_ERROR_UNEXPECTED_TOKEN,
	GAMES_CUE_SHEET_ERROR_UNEXPECTED_EOL,
	GAMES_CUE_SHEET_ERROR_UNEXPECTED_EOF,
	GAMES_CUE_SHEET_ERROR_INVALID_FILE_FORMAT,
	GAMES_CUE_SHEET_ERROR_INVALID_TRACK_NUMBER,
	GAMES_CUE_SHEET_ERROR_INVALID_TRACK_MODE,
	GAMES_CUE_SHEET_ERROR_NOT_A_TRACK
} GamesCueSheetError;
#define GAMES_CUE_SHEET_ERROR games_cue_sheet_error_quark ()


GQuark games_cue_sheet_error_quark (void);


GQuark games_cue_sheet_error_quark (void) {
	return g_quark_from_static_string ("games_cue_sheet_error-quark");
}



