/* steam-error.c generated by valac 0.35.5, the Vala compiler
 * generated from steam-error.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>


typedef enum  {
	GAMES_STEAM_ERROR_NO_APPID,
	GAMES_STEAM_ERROR_NO_NAME
} GamesSteamError;
#define GAMES_STEAM_ERROR games_steam_error_quark ()


GQuark games_steam_error_quark (void);


GQuark games_steam_error_quark (void) {
	return g_quark_from_static_string ("games_steam_error-quark");
}



