/* steam-plugin.c generated by valac 0.35.5, the Vala compiler
 * generated from steam-plugin.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <libgnome-games.h>


#define GAMES_TYPE_STEAM_PLUGIN (games_steam_plugin_get_type ())
#define GAMES_STEAM_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_STEAM_PLUGIN, GamesSteamPlugin))
#define GAMES_STEAM_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_STEAM_PLUGIN, GamesSteamPluginClass))
#define GAMES_IS_STEAM_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_STEAM_PLUGIN))
#define GAMES_IS_STEAM_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_STEAM_PLUGIN))
#define GAMES_STEAM_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_STEAM_PLUGIN, GamesSteamPluginClass))

typedef struct _GamesSteamPlugin GamesSteamPlugin;
typedef struct _GamesSteamPluginClass GamesSteamPluginClass;
typedef struct _GamesSteamPluginPrivate GamesSteamPluginPrivate;

#define GAMES_TYPE_STEAM_GAME_SOURCE (games_steam_game_source_get_type ())
#define GAMES_STEAM_GAME_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_STEAM_GAME_SOURCE, GamesSteamGameSource))
#define GAMES_STEAM_GAME_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_STEAM_GAME_SOURCE, GamesSteamGameSourceClass))
#define GAMES_IS_STEAM_GAME_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_STEAM_GAME_SOURCE))
#define GAMES_IS_STEAM_GAME_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_STEAM_GAME_SOURCE))
#define GAMES_STEAM_GAME_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_STEAM_GAME_SOURCE, GamesSteamGameSourceClass))

typedef struct _GamesSteamGameSource GamesSteamGameSource;
typedef struct _GamesSteamGameSourceClass GamesSteamGameSourceClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _GamesSteamPlugin {
	GObject parent_instance;
	GamesSteamPluginPrivate * priv;
};

struct _GamesSteamPluginClass {
	GObjectClass parent_class;
};


static gpointer games_steam_plugin_parent_class = NULL;
static GamesPluginIface * games_steam_plugin_games_plugin_parent_iface = NULL;
static GType games_steam_plugin_type_id = 0;

GType games_steam_plugin_get_type (void) G_GNUC_CONST;
enum  {
	GAMES_STEAM_PLUGIN_DUMMY_PROPERTY
};
static GamesGameSource* games_steam_plugin_real_get_game_source (GamesPlugin* base, GError** error);
GType games_steam_game_source_get_type (void) G_GNUC_CONST;
GamesSteamGameSource* games_steam_game_source_new (GError** error);
GamesSteamGameSource* games_steam_game_source_construct (GType object_type, GError** error);
GamesSteamPlugin* games_steam_plugin_new (void);
GamesSteamPlugin* games_steam_plugin_construct (GType object_type);
GType register_games_plugin (GTypeModule* module);
GType games_steam_cover_register_type (GTypeModule * module);
GType games_steam_game_source_register_type (GTypeModule * module);
GType games_steam_icon_register_type (GTypeModule * module);
GType games_steam_plugin_register_type (GTypeModule * module);
GType games_steam_registry_register_type (GTypeModule * module);
GType games_steam_registry_value_register_type (GTypeModule * module);
GType games_steam_registry_node_register_type (GTypeModule * module);
GType games_steam_registry_data_register_type (GTypeModule * module);
GType games_steam_title_register_type (GTypeModule * module);


static GamesGameSource* games_steam_plugin_real_get_game_source (GamesPlugin* base, GError** error) {
	GamesSteamPlugin * self;
	GamesGameSource* result = NULL;
	GamesSteamGameSource* _tmp0_;
	GamesSteamGameSource* _tmp1_;
	GamesSteamGameSource* _tmp2_;
	GError * _inner_error_ = NULL;
	self = (GamesSteamPlugin*) base;
	_tmp1_ = games_steam_game_source_new (&_inner_error_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp2_ = _tmp0_;
	_tmp0_ = NULL;
	result = (GamesGameSource*) _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}


GamesSteamPlugin* games_steam_plugin_construct (GType object_type) {
	GamesSteamPlugin * self = NULL;
	self = (GamesSteamPlugin*) g_object_new (object_type, NULL);
	return self;
}


GamesSteamPlugin* games_steam_plugin_new (void) {
	return games_steam_plugin_construct (GAMES_TYPE_STEAM_PLUGIN);
}


static void games_steam_plugin_class_init (GamesSteamPluginClass * klass) {
	games_steam_plugin_parent_class = g_type_class_peek_parent (klass);
}


static void games_steam_plugin_games_plugin_interface_init (GamesPluginIface * iface) {
	games_steam_plugin_games_plugin_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_game_source = (GamesGameSource* (*) (GamesPlugin *, GError**)) games_steam_plugin_real_get_game_source;
}


static void games_steam_plugin_instance_init (GamesSteamPlugin * self) {
}


GType games_steam_plugin_get_type (void) {
	return games_steam_plugin_type_id;
}


GType games_steam_plugin_register_type (GTypeModule * module) {
	static const GTypeInfo g_define_type_info = { sizeof (GamesSteamPluginClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) games_steam_plugin_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GamesSteamPlugin), 0, (GInstanceInitFunc) games_steam_plugin_instance_init, NULL };
	static const GInterfaceInfo games_plugin_info = { (GInterfaceInitFunc) games_steam_plugin_games_plugin_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	games_steam_plugin_type_id = g_type_module_register_type (module, G_TYPE_OBJECT, "GamesSteamPlugin", &g_define_type_info, 0);
	g_type_module_add_interface (module, games_steam_plugin_type_id, GAMES_TYPE_PLUGIN, &games_plugin_info);
	return games_steam_plugin_type_id;
}


GType register_games_plugin (GTypeModule* module) {
	GType result = 0UL;
	g_return_val_if_fail (module != NULL, 0UL);
	games_steam_cover_register_type (module);
	games_steam_game_source_register_type (module);
	games_steam_icon_register_type (module);
	games_steam_plugin_register_type (module);
	games_steam_registry_register_type (module);
	games_steam_registry_value_register_type (module);
	games_steam_registry_node_register_type (module);
	games_steam_registry_data_register_type (module);
	games_steam_title_register_type (module);
	result = GAMES_TYPE_STEAM_PLUGIN;
	return result;
}



