/* preferences-page.c generated by valac 0.35.5, the Vala compiler
 * generated from preferences-page.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>


#define GAMES_TYPE_PREFERENCES_PAGE (games_preferences_page_get_type ())
#define GAMES_PREFERENCES_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_PREFERENCES_PAGE, GamesPreferencesPage))
#define GAMES_IS_PREFERENCES_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_PREFERENCES_PAGE))
#define GAMES_PREFERENCES_PAGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_PREFERENCES_PAGE, GamesPreferencesPageIface))

typedef struct _GamesPreferencesPage GamesPreferencesPage;
typedef struct _GamesPreferencesPageIface GamesPreferencesPageIface;

struct _GamesPreferencesPageIface {
	GTypeInterface parent_iface;
	const gchar* (*get_title) (GamesPreferencesPage* self);
};



GType games_preferences_page_get_type (void) G_GNUC_CONST;
const gchar* games_preferences_page_get_title (GamesPreferencesPage* self);


const gchar* games_preferences_page_get_title (GamesPreferencesPage* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GAMES_PREFERENCES_PAGE_GET_INTERFACE (self)->get_title (self);
}


static void games_preferences_page_base_init (GamesPreferencesPageIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	}
}


GType games_preferences_page_get_type (void) {
	static volatile gsize games_preferences_page_type_id__volatile = 0;
	if (g_once_init_enter (&games_preferences_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesPreferencesPageIface), (GBaseInitFunc) games_preferences_page_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType games_preferences_page_type_id;
		games_preferences_page_type_id = g_type_register_static (G_TYPE_INTERFACE, "GamesPreferencesPage", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (games_preferences_page_type_id, gtk_widget_get_type ());
		g_once_init_leave (&games_preferences_page_type_id__volatile, games_preferences_page_type_id);
	}
	return games_preferences_page_type_id__volatile;
}



