/* icon.c generated by valac 0.35.5, the Vala compiler
 * generated from icon.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>


#define GAMES_TYPE_ICON (games_icon_get_type ())
#define GAMES_ICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_ICON, GamesIcon))
#define GAMES_IS_ICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_ICON))
#define GAMES_ICON_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_ICON, GamesIconIface))

typedef struct _GamesIcon GamesIcon;
typedef struct _GamesIconIface GamesIconIface;

struct _GamesIconIface {
	GTypeInterface parent_iface;
	GIcon* (*get_icon) (GamesIcon* self);
};



GType games_icon_get_type (void) G_GNUC_CONST;
GIcon* games_icon_get_icon (GamesIcon* self);


GIcon* games_icon_get_icon (GamesIcon* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GAMES_ICON_GET_INTERFACE (self)->get_icon (self);
}


static void games_icon_base_init (GamesIconIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType games_icon_get_type (void) {
	static volatile gsize games_icon_type_id__volatile = 0;
	if (g_once_init_enter (&games_icon_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesIconIface), (GBaseInitFunc) games_icon_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType games_icon_type_id;
		games_icon_type_id = g_type_register_static (G_TYPE_INTERFACE, "GamesIcon", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (games_icon_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&games_icon_type_id__volatile, games_icon_type_id);
	}
	return games_icon_type_id__volatile;
}



