/* remote-display.c generated by valac 0.35.5, the Vala compiler
 * generated from remote-display.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>


#define GAMES_TYPE_REMOTE_DISPLAY (games_remote_display_get_type ())
#define GAMES_REMOTE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_REMOTE_DISPLAY, GamesRemoteDisplay))
#define GAMES_REMOTE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_REMOTE_DISPLAY, GamesRemoteDisplayClass))
#define GAMES_IS_REMOTE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_REMOTE_DISPLAY))
#define GAMES_IS_REMOTE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_REMOTE_DISPLAY))
#define GAMES_REMOTE_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_REMOTE_DISPLAY, GamesRemoteDisplayClass))

typedef struct _GamesRemoteDisplay GamesRemoteDisplay;
typedef struct _GamesRemoteDisplayClass GamesRemoteDisplayClass;
typedef struct _GamesRemoteDisplayPrivate GamesRemoteDisplayPrivate;

struct _GamesRemoteDisplay {
	GtkBox parent_instance;
	GamesRemoteDisplayPrivate * priv;
};

struct _GamesRemoteDisplayClass {
	GtkBoxClass parent_class;
};


static gpointer games_remote_display_parent_class = NULL;

GType games_remote_display_get_type (void) G_GNUC_CONST;
enum  {
	GAMES_REMOTE_DISPLAY_DUMMY_PROPERTY
};
GamesRemoteDisplay* games_remote_display_new (void);
GamesRemoteDisplay* games_remote_display_construct (GType object_type);


GamesRemoteDisplay* games_remote_display_construct (GType object_type) {
	GamesRemoteDisplay * self = NULL;
	self = (GamesRemoteDisplay*) g_object_new (object_type, NULL);
	return self;
}


GamesRemoteDisplay* games_remote_display_new (void) {
	return games_remote_display_construct (GAMES_TYPE_REMOTE_DISPLAY);
}


static void games_remote_display_class_init (GamesRemoteDisplayClass * klass) {
	games_remote_display_parent_class = g_type_class_peek_parent (klass);
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Games/ui/remote-display.ui");
}


static void games_remote_display_instance_init (GamesRemoteDisplay * self) {
	gtk_widget_init_template (GTK_WIDGET (self));
}


GType games_remote_display_get_type (void) {
	static volatile gsize games_remote_display_type_id__volatile = 0;
	if (g_once_init_enter (&games_remote_display_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesRemoteDisplayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) games_remote_display_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GamesRemoteDisplay), 0, (GInstanceInitFunc) games_remote_display_instance_init, NULL };
		GType games_remote_display_type_id;
		games_remote_display_type_id = g_type_register_static (gtk_box_get_type (), "GamesRemoteDisplay", &g_define_type_info, 0);
		g_once_init_leave (&games_remote_display_type_id__volatile, games_remote_display_type_id);
	}
	return games_remote_display_type_id__volatile;
}



