/* dummy-icon.c generated by valac 0.35.5, the Vala compiler
 * generated from dummy-icon.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>


#define GAMES_TYPE_ICON (games_icon_get_type ())
#define GAMES_ICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_ICON, GamesIcon))
#define GAMES_IS_ICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_ICON))
#define GAMES_ICON_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_ICON, GamesIconIface))

typedef struct _GamesIcon GamesIcon;
typedef struct _GamesIconIface GamesIconIface;

#define GAMES_TYPE_DUMMY_ICON (games_dummy_icon_get_type ())
#define GAMES_DUMMY_ICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_DUMMY_ICON, GamesDummyIcon))
#define GAMES_DUMMY_ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_DUMMY_ICON, GamesDummyIconClass))
#define GAMES_IS_DUMMY_ICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_DUMMY_ICON))
#define GAMES_IS_DUMMY_ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_DUMMY_ICON))
#define GAMES_DUMMY_ICON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_DUMMY_ICON, GamesDummyIconClass))

typedef struct _GamesDummyIcon GamesDummyIcon;
typedef struct _GamesDummyIconClass GamesDummyIconClass;
typedef struct _GamesDummyIconPrivate GamesDummyIconPrivate;

struct _GamesIconIface {
	GTypeInterface parent_iface;
	GIcon* (*get_icon) (GamesIcon* self);
};

struct _GamesDummyIcon {
	GObject parent_instance;
	GamesDummyIconPrivate * priv;
};

struct _GamesDummyIconClass {
	GObjectClass parent_class;
};


static gpointer games_dummy_icon_parent_class = NULL;
static GamesIconIface * games_dummy_icon_games_icon_parent_iface = NULL;

GType games_icon_get_type (void) G_GNUC_CONST;
GType games_dummy_icon_get_type (void) G_GNUC_CONST;
enum  {
	GAMES_DUMMY_ICON_DUMMY_PROPERTY
};
static GIcon* games_dummy_icon_real_get_icon (GamesIcon* base);
GamesDummyIcon* games_dummy_icon_new (void);
GamesDummyIcon* games_dummy_icon_construct (GType object_type);


static GIcon* games_dummy_icon_real_get_icon (GamesIcon* base) {
	GamesDummyIcon * self;
	GIcon* result = NULL;
	self = (GamesDummyIcon*) base;
	result = NULL;
	return result;
}


GamesDummyIcon* games_dummy_icon_construct (GType object_type) {
	GamesDummyIcon * self = NULL;
	self = (GamesDummyIcon*) g_object_new (object_type, NULL);
	return self;
}


GamesDummyIcon* games_dummy_icon_new (void) {
	return games_dummy_icon_construct (GAMES_TYPE_DUMMY_ICON);
}


static void games_dummy_icon_class_init (GamesDummyIconClass * klass) {
	games_dummy_icon_parent_class = g_type_class_peek_parent (klass);
}


static void games_dummy_icon_games_icon_interface_init (GamesIconIface * iface) {
	games_dummy_icon_games_icon_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_icon = (GIcon* (*) (GamesIcon *)) games_dummy_icon_real_get_icon;
}


static void games_dummy_icon_instance_init (GamesDummyIcon * self) {
}


GType games_dummy_icon_get_type (void) {
	static volatile gsize games_dummy_icon_type_id__volatile = 0;
	if (g_once_init_enter (&games_dummy_icon_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesDummyIconClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) games_dummy_icon_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GamesDummyIcon), 0, (GInstanceInitFunc) games_dummy_icon_instance_init, NULL };
		static const GInterfaceInfo games_icon_info = { (GInterfaceInitFunc) games_dummy_icon_games_icon_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType games_dummy_icon_type_id;
		games_dummy_icon_type_id = g_type_register_static (G_TYPE_OBJECT, "GamesDummyIcon", &g_define_type_info, 0);
		g_type_add_interface_static (games_dummy_icon_type_id, GAMES_TYPE_ICON, &games_icon_info);
		g_once_init_leave (&games_dummy_icon_type_id__volatile, games_dummy_icon_type_id);
	}
	return games_dummy_icon_type_id__volatile;
}



