/* credits.c generated by valac 0.35.5, the Vala compiler
 * generated from credits.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>




#define GAMES_CREDITS_DOCUMENTERS NULL

const gchar* GAMES_CREDITS_AUTHORS[2] = {"Adrien Plazas <kekun.plazas@laposte.net>", "Sebastien Nicouleaud <sebn@users.noreply.github.com>"};
const gchar* GAMES_CREDITS_ARTISTS[1] = {"Adrien Plazas <kekun.plazas@laposte.net>"};


