/* empty-collection.c generated by valac 0.35.5, the Vala compiler
 * generated from empty-collection.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>


#define GAMES_TYPE_EMPTY_COLLECTION (games_empty_collection_get_type ())
#define GAMES_EMPTY_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_EMPTY_COLLECTION, GamesEmptyCollection))
#define GAMES_EMPTY_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_EMPTY_COLLECTION, GamesEmptyCollectionClass))
#define GAMES_IS_EMPTY_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_EMPTY_COLLECTION))
#define GAMES_IS_EMPTY_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_EMPTY_COLLECTION))
#define GAMES_EMPTY_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_EMPTY_COLLECTION, GamesEmptyCollectionClass))

typedef struct _GamesEmptyCollection GamesEmptyCollection;
typedef struct _GamesEmptyCollectionClass GamesEmptyCollectionClass;
typedef struct _GamesEmptyCollectionPrivate GamesEmptyCollectionPrivate;

struct _GamesEmptyCollection {
	GtkBox parent_instance;
	GamesEmptyCollectionPrivate * priv;
};

struct _GamesEmptyCollectionClass {
	GtkBoxClass parent_class;
};


static gpointer games_empty_collection_parent_class = NULL;

GType games_empty_collection_get_type (void) G_GNUC_CONST;
enum  {
	GAMES_EMPTY_COLLECTION_DUMMY_PROPERTY
};
GamesEmptyCollection* games_empty_collection_new (void);
GamesEmptyCollection* games_empty_collection_construct (GType object_type);


GamesEmptyCollection* games_empty_collection_construct (GType object_type) {
	GamesEmptyCollection * self = NULL;
	self = (GamesEmptyCollection*) g_object_new (object_type, NULL);
	return self;
}


GamesEmptyCollection* games_empty_collection_new (void) {
	return games_empty_collection_construct (GAMES_TYPE_EMPTY_COLLECTION);
}


static void games_empty_collection_class_init (GamesEmptyCollectionClass * klass) {
	games_empty_collection_parent_class = g_type_class_peek_parent (klass);
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Games/ui/empty-collection.ui");
}


static void games_empty_collection_instance_init (GamesEmptyCollection * self) {
	gtk_widget_init_template (GTK_WIDGET (self));
}


GType games_empty_collection_get_type (void) {
	static volatile gsize games_empty_collection_type_id__volatile = 0;
	if (g_once_init_enter (&games_empty_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesEmptyCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) games_empty_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GamesEmptyCollection), 0, (GInstanceInitFunc) games_empty_collection_instance_init, NULL };
		GType games_empty_collection_type_id;
		games_empty_collection_type_id = g_type_register_static (gtk_box_get_type (), "GamesEmptyCollection", &g_define_type_info, 0);
		g_once_init_leave (&games_empty_collection_type_id__volatile, games_empty_collection_type_id);
	}
	return games_empty_collection_type_id__volatile;
}



