/* libretro-plugin.c generated by valac 0.35.5, the Vala compiler
 * generated from libretro-plugin.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <libgnome-games.h>


#define GAMES_TYPE_LIBRETRO_PLUGIN (games_libretro_plugin_get_type ())
#define GAMES_LIBRETRO_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_LIBRETRO_PLUGIN, GamesLibretroPlugin))
#define GAMES_LIBRETRO_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_LIBRETRO_PLUGIN, GamesLibretroPluginClass))
#define GAMES_IS_LIBRETRO_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_LIBRETRO_PLUGIN))
#define GAMES_IS_LIBRETRO_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_LIBRETRO_PLUGIN))
#define GAMES_LIBRETRO_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_LIBRETRO_PLUGIN, GamesLibretroPluginClass))

typedef struct _GamesLibretroPlugin GamesLibretroPlugin;
typedef struct _GamesLibretroPluginClass GamesLibretroPluginClass;
typedef struct _GamesLibretroPluginPrivate GamesLibretroPluginPrivate;

#define GAMES_TYPE_LIBRETRO_GAME_SOURCE (games_libretro_game_source_get_type ())
#define GAMES_LIBRETRO_GAME_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_LIBRETRO_GAME_SOURCE, GamesLibretroGameSource))
#define GAMES_LIBRETRO_GAME_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_LIBRETRO_GAME_SOURCE, GamesLibretroGameSourceClass))
#define GAMES_IS_LIBRETRO_GAME_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_LIBRETRO_GAME_SOURCE))
#define GAMES_IS_LIBRETRO_GAME_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_LIBRETRO_GAME_SOURCE))
#define GAMES_LIBRETRO_GAME_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_LIBRETRO_GAME_SOURCE, GamesLibretroGameSourceClass))

typedef struct _GamesLibretroGameSource GamesLibretroGameSource;
typedef struct _GamesLibretroGameSourceClass GamesLibretroGameSourceClass;

struct _GamesLibretroPlugin {
	GObject parent_instance;
	GamesLibretroPluginPrivate * priv;
};

struct _GamesLibretroPluginClass {
	GObjectClass parent_class;
};


static gpointer games_libretro_plugin_parent_class = NULL;
static GamesPluginIface * games_libretro_plugin_games_plugin_parent_iface = NULL;
static GType games_libretro_plugin_type_id = 0;

GType games_libretro_plugin_get_type (void) G_GNUC_CONST;
enum  {
	GAMES_LIBRETRO_PLUGIN_DUMMY_PROPERTY
};
static GamesGameSource* games_libretro_plugin_real_get_game_source (GamesPlugin* base, GError** error);
GamesLibretroGameSource* games_libretro_game_source_new (void);
GamesLibretroGameSource* games_libretro_game_source_construct (GType object_type);
GType games_libretro_game_source_get_type (void) G_GNUC_CONST;
GamesLibretroPlugin* games_libretro_plugin_new (void);
GamesLibretroPlugin* games_libretro_plugin_construct (GType object_type);
GType register_games_plugin (GTypeModule* module);
GType games_libretro_game_source_register_type (GTypeModule * module);
GType games_libretro_icon_register_type (GTypeModule * module);
GType games_libretro_plugin_register_type (GTypeModule * module);
GType games_libretro_title_register_type (GTypeModule * module);
GType games_libretro_uid_register_type (GTypeModule * module);


static GamesGameSource* games_libretro_plugin_real_get_game_source (GamesPlugin* base, GError** error) {
	GamesLibretroPlugin * self;
	GamesGameSource* result = NULL;
	GamesLibretroGameSource* _tmp0_;
	self = (GamesLibretroPlugin*) base;
	_tmp0_ = games_libretro_game_source_new ();
	result = (GamesGameSource*) _tmp0_;
	return result;
}


GamesLibretroPlugin* games_libretro_plugin_construct (GType object_type) {
	GamesLibretroPlugin * self = NULL;
	self = (GamesLibretroPlugin*) g_object_new (object_type, NULL);
	return self;
}


GamesLibretroPlugin* games_libretro_plugin_new (void) {
	return games_libretro_plugin_construct (GAMES_TYPE_LIBRETRO_PLUGIN);
}


static void games_libretro_plugin_class_init (GamesLibretroPluginClass * klass) {
	games_libretro_plugin_parent_class = g_type_class_peek_parent (klass);
}


static void games_libretro_plugin_games_plugin_interface_init (GamesPluginIface * iface) {
	games_libretro_plugin_games_plugin_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_game_source = (GamesGameSource* (*) (GamesPlugin *, GError**)) games_libretro_plugin_real_get_game_source;
}


static void games_libretro_plugin_instance_init (GamesLibretroPlugin * self) {
}


GType games_libretro_plugin_get_type (void) {
	return games_libretro_plugin_type_id;
}


GType games_libretro_plugin_register_type (GTypeModule * module) {
	static const GTypeInfo g_define_type_info = { sizeof (GamesLibretroPluginClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) games_libretro_plugin_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GamesLibretroPlugin), 0, (GInstanceInitFunc) games_libretro_plugin_instance_init, NULL };
	static const GInterfaceInfo games_plugin_info = { (GInterfaceInitFunc) games_libretro_plugin_games_plugin_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	games_libretro_plugin_type_id = g_type_module_register_type (module, G_TYPE_OBJECT, "GamesLibretroPlugin", &g_define_type_info, 0);
	g_type_module_add_interface (module, games_libretro_plugin_type_id, GAMES_TYPE_PLUGIN, &games_plugin_info);
	return games_libretro_plugin_type_id;
}


GType register_games_plugin (GTypeModule* module) {
	GType result = 0UL;
	g_return_val_if_fail (module != NULL, 0UL);
	games_libretro_game_source_register_type (module);
	games_libretro_icon_register_type (module);
	games_libretro_plugin_register_type (module);
	games_libretro_title_register_type (module);
	games_libretro_uid_register_type (module);
	result = GAMES_TYPE_LIBRETRO_PLUGIN;
	return result;
}



