/* libgnome-games.h generated by valac 0.35.5, the Vala compiler, do not modify */


#ifndef __LIBGNOME_GAMES_H__
#define __LIBGNOME_GAMES_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <retro-gtk.h>
#include <libtracker-sparql/tracker-sparql.h>

G_BEGIN_DECLS


#define GAMES_TYPE_RUNNER (games_runner_get_type ())
#define GAMES_RUNNER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_RUNNER, GamesRunner))
#define GAMES_IS_RUNNER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_RUNNER))
#define GAMES_RUNNER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_RUNNER, GamesRunnerIface))

typedef struct _GamesRunner GamesRunner;
typedef struct _GamesRunnerIface GamesRunnerIface;

#define GAMES_TYPE_MEDIA_SET (games_media_set_get_type ())
#define GAMES_MEDIA_SET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_MEDIA_SET, GamesMediaSet))
#define GAMES_MEDIA_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_MEDIA_SET, GamesMediaSetClass))
#define GAMES_IS_MEDIA_SET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_MEDIA_SET))
#define GAMES_IS_MEDIA_SET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_MEDIA_SET))
#define GAMES_MEDIA_SET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_MEDIA_SET, GamesMediaSetClass))

typedef struct _GamesMediaSet GamesMediaSet;
typedef struct _GamesMediaSetClass GamesMediaSetClass;

#define GAMES_TYPE_COMMAND_RUNNER (games_command_runner_get_type ())
#define GAMES_COMMAND_RUNNER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_COMMAND_RUNNER, GamesCommandRunner))
#define GAMES_COMMAND_RUNNER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_COMMAND_RUNNER, GamesCommandRunnerClass))
#define GAMES_IS_COMMAND_RUNNER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_COMMAND_RUNNER))
#define GAMES_IS_COMMAND_RUNNER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_COMMAND_RUNNER))
#define GAMES_COMMAND_RUNNER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_COMMAND_RUNNER, GamesCommandRunnerClass))

typedef struct _GamesCommandRunner GamesCommandRunner;
typedef struct _GamesCommandRunnerClass GamesCommandRunnerClass;
typedef struct _GamesCommandRunnerPrivate GamesCommandRunnerPrivate;

#define GAMES_TYPE_COVER (games_cover_get_type ())
#define GAMES_COVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_COVER, GamesCover))
#define GAMES_IS_COVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_COVER))
#define GAMES_COVER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_COVER, GamesCoverIface))

typedef struct _GamesCover GamesCover;
typedef struct _GamesCoverIface GamesCoverIface;

#define GAMES_TYPE_GAME (games_game_get_type ())
#define GAMES_GAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GAME, GamesGame))
#define GAMES_IS_GAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GAME))
#define GAMES_GAME_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_GAME, GamesGameIface))

typedef struct _GamesGame GamesGame;
typedef struct _GamesGameIface GamesGameIface;

#define GAMES_TYPE_ICON (games_icon_get_type ())
#define GAMES_ICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_ICON, GamesIcon))
#define GAMES_IS_ICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_ICON))
#define GAMES_ICON_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_ICON, GamesIconIface))

typedef struct _GamesIcon GamesIcon;
typedef struct _GamesIconIface GamesIconIface;

#define GAMES_TYPE_GAME_SOURCE (games_game_source_get_type ())
#define GAMES_GAME_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GAME_SOURCE, GamesGameSource))
#define GAMES_IS_GAME_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GAME_SOURCE))
#define GAMES_GAME_SOURCE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_GAME_SOURCE, GamesGameSourceIface))

typedef struct _GamesGameSource GamesGameSource;
typedef struct _GamesGameSourceIface GamesGameSourceIface;

#define GAMES_TYPE_GAME_URI_ADAPTER (games_game_uri_adapter_get_type ())
#define GAMES_GAME_URI_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GAME_URI_ADAPTER, GamesGameUriAdapter))
#define GAMES_IS_GAME_URI_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GAME_URI_ADAPTER))
#define GAMES_GAME_URI_ADAPTER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_GAME_URI_ADAPTER, GamesGameUriAdapterIface))

typedef struct _GamesGameUriAdapter GamesGameUriAdapter;
typedef struct _GamesGameUriAdapterIface GamesGameUriAdapterIface;

#define GAMES_TYPE_INPUT_CAPABILITIES (games_input_capabilities_get_type ())
#define GAMES_INPUT_CAPABILITIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_INPUT_CAPABILITIES, GamesInputCapabilities))
#define GAMES_IS_INPUT_CAPABILITIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_INPUT_CAPABILITIES))
#define GAMES_INPUT_CAPABILITIES_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_INPUT_CAPABILITIES, GamesInputCapabilitiesIface))

typedef struct _GamesInputCapabilities GamesInputCapabilities;
typedef struct _GamesInputCapabilitiesIface GamesInputCapabilitiesIface;

#define GAMES_TYPE_MEDIA (games_media_get_type ())
#define GAMES_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_MEDIA, GamesMedia))
#define GAMES_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_MEDIA, GamesMediaClass))
#define GAMES_IS_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_MEDIA))
#define GAMES_IS_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_MEDIA))
#define GAMES_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_MEDIA, GamesMediaClass))

typedef struct _GamesMedia GamesMedia;
typedef struct _GamesMediaClass GamesMediaClass;
typedef struct _GamesMediaPrivate GamesMediaPrivate;

#define GAMES_TYPE_TITLE (games_title_get_type ())
#define GAMES_TITLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_TITLE, GamesTitle))
#define GAMES_IS_TITLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_TITLE))
#define GAMES_TITLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_TITLE, GamesTitleIface))

typedef struct _GamesTitle GamesTitle;
typedef struct _GamesTitleIface GamesTitleIface;
typedef struct _GamesMediaSetPrivate GamesMediaSetPrivate;

#define GAMES_TYPE_PLUGIN (games_plugin_get_type ())
#define GAMES_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_PLUGIN, GamesPlugin))
#define GAMES_IS_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_PLUGIN))
#define GAMES_PLUGIN_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_PLUGIN, GamesPluginIface))

typedef struct _GamesPlugin GamesPlugin;
typedef struct _GamesPluginIface GamesPluginIface;

#define GAMES_TYPE_UID (games_uid_get_type ())
#define GAMES_UID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_UID, GamesUid))
#define GAMES_IS_UID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_UID))
#define GAMES_UID_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_UID, GamesUidIface))

typedef struct _GamesUid GamesUid;
typedef struct _GamesUidIface GamesUidIface;

#define GAMES_TYPE_URI_GAME_FACTORY (games_uri_game_factory_get_type ())
#define GAMES_URI_GAME_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_URI_GAME_FACTORY, GamesUriGameFactory))
#define GAMES_IS_URI_GAME_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_URI_GAME_FACTORY))
#define GAMES_URI_GAME_FACTORY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_URI_GAME_FACTORY, GamesUriGameFactoryIface))

typedef struct _GamesUriGameFactory GamesUriGameFactory;
typedef struct _GamesUriGameFactoryIface GamesUriGameFactoryIface;

#define GAMES_TYPE_DUMMY_COVER (games_dummy_cover_get_type ())
#define GAMES_DUMMY_COVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_DUMMY_COVER, GamesDummyCover))
#define GAMES_DUMMY_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_DUMMY_COVER, GamesDummyCoverClass))
#define GAMES_IS_DUMMY_COVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_DUMMY_COVER))
#define GAMES_IS_DUMMY_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_DUMMY_COVER))
#define GAMES_DUMMY_COVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_DUMMY_COVER, GamesDummyCoverClass))

typedef struct _GamesDummyCover GamesDummyCover;
typedef struct _GamesDummyCoverClass GamesDummyCoverClass;
typedef struct _GamesDummyCoverPrivate GamesDummyCoverPrivate;

#define GAMES_TYPE_DUMMY_ICON (games_dummy_icon_get_type ())
#define GAMES_DUMMY_ICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_DUMMY_ICON, GamesDummyIcon))
#define GAMES_DUMMY_ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_DUMMY_ICON, GamesDummyIconClass))
#define GAMES_IS_DUMMY_ICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_DUMMY_ICON))
#define GAMES_IS_DUMMY_ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_DUMMY_ICON))
#define GAMES_DUMMY_ICON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_DUMMY_ICON, GamesDummyIconClass))

typedef struct _GamesDummyIcon GamesDummyIcon;
typedef struct _GamesDummyIconClass GamesDummyIconClass;
typedef struct _GamesDummyIconPrivate GamesDummyIconPrivate;

#define GAMES_TYPE_GAMEINFO_DOC (games_gameinfo_doc_get_type ())
#define GAMES_GAMEINFO_DOC(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GAMEINFO_DOC, GamesGameinfoDoc))
#define GAMES_GAMEINFO_DOC_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GAMEINFO_DOC, GamesGameinfoDocClass))
#define GAMES_IS_GAMEINFO_DOC(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GAMEINFO_DOC))
#define GAMES_IS_GAMEINFO_DOC_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GAMEINFO_DOC))
#define GAMES_GAMEINFO_DOC_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GAMEINFO_DOC, GamesGameinfoDocClass))

typedef struct _GamesGameinfoDoc GamesGameinfoDoc;
typedef struct _GamesGameinfoDocClass GamesGameinfoDocClass;
typedef struct _GamesGameinfoDocPrivate GamesGameinfoDocPrivate;

#define GAMES_TYPE_GAMEINFO_DISC_ID_DISC_TITLE (games_gameinfo_disc_id_disc_title_get_type ())
#define GAMES_GAMEINFO_DISC_ID_DISC_TITLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GAMEINFO_DISC_ID_DISC_TITLE, GamesGameinfoDiscIdDiscTitle))
#define GAMES_GAMEINFO_DISC_ID_DISC_TITLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GAMEINFO_DISC_ID_DISC_TITLE, GamesGameinfoDiscIdDiscTitleClass))
#define GAMES_IS_GAMEINFO_DISC_ID_DISC_TITLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GAMEINFO_DISC_ID_DISC_TITLE))
#define GAMES_IS_GAMEINFO_DISC_ID_DISC_TITLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GAMEINFO_DISC_ID_DISC_TITLE))
#define GAMES_GAMEINFO_DISC_ID_DISC_TITLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GAMEINFO_DISC_ID_DISC_TITLE, GamesGameinfoDiscIdDiscTitleClass))

typedef struct _GamesGameinfoDiscIdDiscTitle GamesGameinfoDiscIdDiscTitle;
typedef struct _GamesGameinfoDiscIdDiscTitleClass GamesGameinfoDiscIdDiscTitleClass;
typedef struct _GamesGameinfoDiscIdDiscTitlePrivate GamesGameinfoDiscIdDiscTitlePrivate;

#define GAMES_TYPE_GAMEINFO_DISC_ID_GAME_TITLE (games_gameinfo_disc_id_game_title_get_type ())
#define GAMES_GAMEINFO_DISC_ID_GAME_TITLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GAMEINFO_DISC_ID_GAME_TITLE, GamesGameinfoDiscIdGameTitle))
#define GAMES_GAMEINFO_DISC_ID_GAME_TITLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GAMEINFO_DISC_ID_GAME_TITLE, GamesGameinfoDiscIdGameTitleClass))
#define GAMES_IS_GAMEINFO_DISC_ID_GAME_TITLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GAMEINFO_DISC_ID_GAME_TITLE))
#define GAMES_IS_GAMEINFO_DISC_ID_GAME_TITLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GAMEINFO_DISC_ID_GAME_TITLE))
#define GAMES_GAMEINFO_DISC_ID_GAME_TITLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GAMEINFO_DISC_ID_GAME_TITLE, GamesGameinfoDiscIdGameTitleClass))

typedef struct _GamesGameinfoDiscIdGameTitle GamesGameinfoDiscIdGameTitle;
typedef struct _GamesGameinfoDiscIdGameTitleClass GamesGameinfoDiscIdGameTitleClass;
typedef struct _GamesGameinfoDiscIdGameTitlePrivate GamesGameinfoDiscIdGameTitlePrivate;

#define GAMES_TYPE_GAMEINFO_DISC_ID_INPUT_CAPABILITIES (games_gameinfo_disc_id_input_capabilities_get_type ())
#define GAMES_GAMEINFO_DISC_ID_INPUT_CAPABILITIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GAMEINFO_DISC_ID_INPUT_CAPABILITIES, GamesGameinfoDiscIdInputCapabilities))
#define GAMES_GAMEINFO_DISC_ID_INPUT_CAPABILITIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GAMEINFO_DISC_ID_INPUT_CAPABILITIES, GamesGameinfoDiscIdInputCapabilitiesClass))
#define GAMES_IS_GAMEINFO_DISC_ID_INPUT_CAPABILITIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GAMEINFO_DISC_ID_INPUT_CAPABILITIES))
#define GAMES_IS_GAMEINFO_DISC_ID_INPUT_CAPABILITIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GAMEINFO_DISC_ID_INPUT_CAPABILITIES))
#define GAMES_GAMEINFO_DISC_ID_INPUT_CAPABILITIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GAMEINFO_DISC_ID_INPUT_CAPABILITIES, GamesGameinfoDiscIdInputCapabilitiesClass))

typedef struct _GamesGameinfoDiscIdInputCapabilities GamesGameinfoDiscIdInputCapabilities;
typedef struct _GamesGameinfoDiscIdInputCapabilitiesClass GamesGameinfoDiscIdInputCapabilitiesClass;
typedef struct _GamesGameinfoDiscIdInputCapabilitiesPrivate GamesGameinfoDiscIdInputCapabilitiesPrivate;

#define GAMES_TYPE_GENERIC_GAME (games_generic_game_get_type ())
#define GAMES_GENERIC_GAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GENERIC_GAME, GamesGenericGame))
#define GAMES_GENERIC_GAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GENERIC_GAME, GamesGenericGameClass))
#define GAMES_IS_GENERIC_GAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GENERIC_GAME))
#define GAMES_IS_GENERIC_GAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GENERIC_GAME))
#define GAMES_GENERIC_GAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GENERIC_GAME, GamesGenericGameClass))

typedef struct _GamesGenericGame GamesGenericGame;
typedef struct _GamesGenericGameClass GamesGenericGameClass;
typedef struct _GamesGenericGamePrivate GamesGenericGamePrivate;

#define GAMES_TYPE_GENERIC_SYNC_GAME_URI_ADAPTER (games_generic_sync_game_uri_adapter_get_type ())
#define GAMES_GENERIC_SYNC_GAME_URI_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GENERIC_SYNC_GAME_URI_ADAPTER, GamesGenericSyncGameUriAdapter))
#define GAMES_GENERIC_SYNC_GAME_URI_ADAPTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GENERIC_SYNC_GAME_URI_ADAPTER, GamesGenericSyncGameUriAdapterClass))
#define GAMES_IS_GENERIC_SYNC_GAME_URI_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GENERIC_SYNC_GAME_URI_ADAPTER))
#define GAMES_IS_GENERIC_SYNC_GAME_URI_ADAPTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GENERIC_SYNC_GAME_URI_ADAPTER))
#define GAMES_GENERIC_SYNC_GAME_URI_ADAPTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GENERIC_SYNC_GAME_URI_ADAPTER, GamesGenericSyncGameUriAdapterClass))

typedef struct _GamesGenericSyncGameUriAdapter GamesGenericSyncGameUriAdapter;
typedef struct _GamesGenericSyncGameUriAdapterClass GamesGenericSyncGameUriAdapterClass;
typedef struct _GamesGenericSyncGameUriAdapterPrivate GamesGenericSyncGameUriAdapterPrivate;

#define GAMES_TYPE_GENERIC_TITLE (games_generic_title_get_type ())
#define GAMES_GENERIC_TITLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GENERIC_TITLE, GamesGenericTitle))
#define GAMES_GENERIC_TITLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GENERIC_TITLE, GamesGenericTitleClass))
#define GAMES_IS_GENERIC_TITLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GENERIC_TITLE))
#define GAMES_IS_GENERIC_TITLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GENERIC_TITLE))
#define GAMES_GENERIC_TITLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GENERIC_TITLE, GamesGenericTitleClass))

typedef struct _GamesGenericTitle GamesGenericTitle;
typedef struct _GamesGenericTitleClass GamesGenericTitleClass;
typedef struct _GamesGenericTitlePrivate GamesGenericTitlePrivate;

#define GAMES_TYPE_GENERIC_UID (games_generic_uid_get_type ())
#define GAMES_GENERIC_UID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GENERIC_UID, GamesGenericUid))
#define GAMES_GENERIC_UID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GENERIC_UID, GamesGenericUidClass))
#define GAMES_IS_GENERIC_UID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GENERIC_UID))
#define GAMES_IS_GENERIC_UID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GENERIC_UID))
#define GAMES_GENERIC_UID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GENERIC_UID, GamesGenericUidClass))

typedef struct _GamesGenericUid GamesGenericUid;
typedef struct _GamesGenericUidClass GamesGenericUidClass;
typedef struct _GamesGenericUidPrivate GamesGenericUidPrivate;

#define GAMES_TYPE_GENERIC_URI_GAME_FACTORY (games_generic_uri_game_factory_get_type ())
#define GAMES_GENERIC_URI_GAME_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GENERIC_URI_GAME_FACTORY, GamesGenericUriGameFactory))
#define GAMES_GENERIC_URI_GAME_FACTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GENERIC_URI_GAME_FACTORY, GamesGenericUriGameFactoryClass))
#define GAMES_IS_GENERIC_URI_GAME_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GENERIC_URI_GAME_FACTORY))
#define GAMES_IS_GENERIC_URI_GAME_FACTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GENERIC_URI_GAME_FACTORY))
#define GAMES_GENERIC_URI_GAME_FACTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GENERIC_URI_GAME_FACTORY, GamesGenericUriGameFactoryClass))

typedef struct _GamesGenericUriGameFactory GamesGenericUriGameFactory;
typedef struct _GamesGenericUriGameFactoryClass GamesGenericUriGameFactoryClass;
typedef struct _GamesGenericUriGameFactoryPrivate GamesGenericUriGameFactoryPrivate;

#define GAMES_TYPE_GRILO_COVER (games_grilo_cover_get_type ())
#define GAMES_GRILO_COVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GRILO_COVER, GamesGriloCover))
#define GAMES_GRILO_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GRILO_COVER, GamesGriloCoverClass))
#define GAMES_IS_GRILO_COVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GRILO_COVER))
#define GAMES_IS_GRILO_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GRILO_COVER))
#define GAMES_GRILO_COVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GRILO_COVER, GamesGriloCoverClass))

typedef struct _GamesGriloCover GamesGriloCover;
typedef struct _GamesGriloCoverClass GamesGriloCoverClass;
typedef struct _GamesGriloCoverPrivate GamesGriloCoverPrivate;

#define GAMES_TYPE_GRILO_MEDIA (games_grilo_media_get_type ())
#define GAMES_GRILO_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_GRILO_MEDIA, GamesGriloMedia))
#define GAMES_GRILO_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_GRILO_MEDIA, GamesGriloMediaClass))
#define GAMES_IS_GRILO_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_GRILO_MEDIA))
#define GAMES_IS_GRILO_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_GRILO_MEDIA))
#define GAMES_GRILO_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_GRILO_MEDIA, GamesGriloMediaClass))

typedef struct _GamesGriloMedia GamesGriloMedia;
typedef struct _GamesGriloMediaClass GamesGriloMediaClass;
typedef struct _GamesGriloMediaPrivate GamesGriloMediaPrivate;

#define GAMES_TYPE_RETRO_CORE_SOURCE (games_retro_core_source_get_type ())
#define GAMES_RETRO_CORE_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_RETRO_CORE_SOURCE, GamesRetroCoreSource))
#define GAMES_RETRO_CORE_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_RETRO_CORE_SOURCE, GamesRetroCoreSourceClass))
#define GAMES_IS_RETRO_CORE_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_RETRO_CORE_SOURCE))
#define GAMES_IS_RETRO_CORE_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_RETRO_CORE_SOURCE))
#define GAMES_RETRO_CORE_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_RETRO_CORE_SOURCE, GamesRetroCoreSourceClass))

typedef struct _GamesRetroCoreSource GamesRetroCoreSource;
typedef struct _GamesRetroCoreSourceClass GamesRetroCoreSourceClass;
typedef struct _GamesRetroCoreSourcePrivate GamesRetroCoreSourcePrivate;

#define GAMES_TYPE_RETRO_RUNNER (games_retro_runner_get_type ())
#define GAMES_RETRO_RUNNER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_RETRO_RUNNER, GamesRetroRunner))
#define GAMES_RETRO_RUNNER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_RETRO_RUNNER, GamesRetroRunnerClass))
#define GAMES_IS_RETRO_RUNNER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_RETRO_RUNNER))
#define GAMES_IS_RETRO_RUNNER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_RETRO_RUNNER))
#define GAMES_RETRO_RUNNER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_RETRO_RUNNER, GamesRetroRunnerClass))

typedef struct _GamesRetroRunner GamesRetroRunner;
typedef struct _GamesRetroRunnerClass GamesRetroRunnerClass;
typedef struct _GamesRetroRunnerPrivate GamesRetroRunnerPrivate;

#define GAMES_TYPE_TRACKER_QUERY (games_tracker_query_get_type ())
#define GAMES_TRACKER_QUERY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_TRACKER_QUERY, GamesTrackerQuery))
#define GAMES_IS_TRACKER_QUERY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_TRACKER_QUERY))
#define GAMES_TRACKER_QUERY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GAMES_TYPE_TRACKER_QUERY, GamesTrackerQueryIface))

typedef struct _GamesTrackerQuery GamesTrackerQuery;
typedef struct _GamesTrackerQueryIface GamesTrackerQueryIface;

#define GAMES_TYPE_MIME_TYPE_TRACKER_QUERY (games_mime_type_tracker_query_get_type ())
#define GAMES_MIME_TYPE_TRACKER_QUERY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_MIME_TYPE_TRACKER_QUERY, GamesMimeTypeTrackerQuery))
#define GAMES_MIME_TYPE_TRACKER_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_MIME_TYPE_TRACKER_QUERY, GamesMimeTypeTrackerQueryClass))
#define GAMES_IS_MIME_TYPE_TRACKER_QUERY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_MIME_TYPE_TRACKER_QUERY))
#define GAMES_IS_MIME_TYPE_TRACKER_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_MIME_TYPE_TRACKER_QUERY))
#define GAMES_MIME_TYPE_TRACKER_QUERY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_MIME_TYPE_TRACKER_QUERY, GamesMimeTypeTrackerQueryClass))

typedef struct _GamesMimeTypeTrackerQuery GamesMimeTypeTrackerQuery;
typedef struct _GamesMimeTypeTrackerQueryClass GamesMimeTypeTrackerQueryClass;
typedef struct _GamesMimeTypeTrackerQueryPrivate GamesMimeTypeTrackerQueryPrivate;

#define GAMES_TYPE_TRACKER_GAME_SOURCE (games_tracker_game_source_get_type ())
#define GAMES_TRACKER_GAME_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_TRACKER_GAME_SOURCE, GamesTrackerGameSource))
#define GAMES_TRACKER_GAME_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_TRACKER_GAME_SOURCE, GamesTrackerGameSourceClass))
#define GAMES_IS_TRACKER_GAME_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_TRACKER_GAME_SOURCE))
#define GAMES_IS_TRACKER_GAME_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_TRACKER_GAME_SOURCE))
#define GAMES_TRACKER_GAME_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_TRACKER_GAME_SOURCE, GamesTrackerGameSourceClass))

typedef struct _GamesTrackerGameSource GamesTrackerGameSource;
typedef struct _GamesTrackerGameSourceClass GamesTrackerGameSourceClass;
typedef struct _GamesTrackerGameSourcePrivate GamesTrackerGameSourcePrivate;

#define GAMES_TYPE_APPLICATION (games_application_get_type ())
#define GAMES_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_APPLICATION, GamesApplication))
#define GAMES_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_APPLICATION, GamesApplicationClass))
#define GAMES_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_APPLICATION))
#define GAMES_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_APPLICATION))
#define GAMES_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_APPLICATION, GamesApplicationClass))

typedef struct _GamesApplication GamesApplication;
typedef struct _GamesApplicationClass GamesApplicationClass;
typedef struct _GamesApplicationPrivate GamesApplicationPrivate;

#define GAMES_TYPE_REMOTE_DISPLAY (games_remote_display_get_type ())
#define GAMES_REMOTE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_REMOTE_DISPLAY, GamesRemoteDisplay))
#define GAMES_REMOTE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_REMOTE_DISPLAY, GamesRemoteDisplayClass))
#define GAMES_IS_REMOTE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_REMOTE_DISPLAY))
#define GAMES_IS_REMOTE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_REMOTE_DISPLAY))
#define GAMES_REMOTE_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_REMOTE_DISPLAY, GamesRemoteDisplayClass))

typedef struct _GamesRemoteDisplay GamesRemoteDisplay;
typedef struct _GamesRemoteDisplayClass GamesRemoteDisplayClass;
typedef struct _GamesRemoteDisplayPrivate GamesRemoteDisplayPrivate;

#define GAMES_TYPE_COMPOSITE_COVER (games_composite_cover_get_type ())
#define GAMES_COMPOSITE_COVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_COMPOSITE_COVER, GamesCompositeCover))
#define GAMES_COMPOSITE_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_COMPOSITE_COVER, GamesCompositeCoverClass))
#define GAMES_IS_COMPOSITE_COVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_COMPOSITE_COVER))
#define GAMES_IS_COMPOSITE_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_COMPOSITE_COVER))
#define GAMES_COMPOSITE_COVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_COMPOSITE_COVER, GamesCompositeCoverClass))

typedef struct _GamesCompositeCover GamesCompositeCover;
typedef struct _GamesCompositeCoverClass GamesCompositeCoverClass;
typedef struct _GamesCompositeCoverPrivate GamesCompositeCoverPrivate;

#define GAMES_TYPE_COMPOSITE_TITLE (games_composite_title_get_type ())
#define GAMES_COMPOSITE_TITLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_COMPOSITE_TITLE, GamesCompositeTitle))
#define GAMES_COMPOSITE_TITLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_COMPOSITE_TITLE, GamesCompositeTitleClass))
#define GAMES_IS_COMPOSITE_TITLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_COMPOSITE_TITLE))
#define GAMES_IS_COMPOSITE_TITLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_COMPOSITE_TITLE))
#define GAMES_COMPOSITE_TITLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_COMPOSITE_TITLE, GamesCompositeTitleClass))

typedef struct _GamesCompositeTitle GamesCompositeTitle;
typedef struct _GamesCompositeTitleClass GamesCompositeTitleClass;
typedef struct _GamesCompositeTitlePrivate GamesCompositeTitlePrivate;

#define GAMES_TYPE_CUE_SHEET (games_cue_sheet_get_type ())
#define GAMES_CUE_SHEET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_CUE_SHEET, GamesCueSheet))
#define GAMES_CUE_SHEET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_CUE_SHEET, GamesCueSheetClass))
#define GAMES_IS_CUE_SHEET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_CUE_SHEET))
#define GAMES_IS_CUE_SHEET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_CUE_SHEET))
#define GAMES_CUE_SHEET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_CUE_SHEET, GamesCueSheetClass))

typedef struct _GamesCueSheet GamesCueSheet;
typedef struct _GamesCueSheetClass GamesCueSheetClass;
typedef struct _GamesCueSheetPrivate GamesCueSheetPrivate;

#define GAMES_TYPE_CUE_SHEET_TRACK_NODE (games_cue_sheet_track_node_get_type ())
#define GAMES_CUE_SHEET_TRACK_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_CUE_SHEET_TRACK_NODE, GamesCueSheetTrackNode))
#define GAMES_CUE_SHEET_TRACK_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_CUE_SHEET_TRACK_NODE, GamesCueSheetTrackNodeClass))
#define GAMES_IS_CUE_SHEET_TRACK_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_CUE_SHEET_TRACK_NODE))
#define GAMES_IS_CUE_SHEET_TRACK_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_CUE_SHEET_TRACK_NODE))
#define GAMES_CUE_SHEET_TRACK_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_CUE_SHEET_TRACK_NODE, GamesCueSheetTrackNodeClass))

typedef struct _GamesCueSheetTrackNode GamesCueSheetTrackNode;
typedef struct _GamesCueSheetTrackNodeClass GamesCueSheetTrackNodeClass;

#define GAMES_TYPE_CUE_SHEET_FILE_FORMAT (games_cue_sheet_file_format_get_type ())

#define GAMES_TYPE_CUE_SHEET_FILE_NODE (games_cue_sheet_file_node_get_type ())
#define GAMES_CUE_SHEET_FILE_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_CUE_SHEET_FILE_NODE, GamesCueSheetFileNode))
#define GAMES_CUE_SHEET_FILE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_CUE_SHEET_FILE_NODE, GamesCueSheetFileNodeClass))
#define GAMES_IS_CUE_SHEET_FILE_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_CUE_SHEET_FILE_NODE))
#define GAMES_IS_CUE_SHEET_FILE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_CUE_SHEET_FILE_NODE))
#define GAMES_CUE_SHEET_FILE_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_CUE_SHEET_FILE_NODE, GamesCueSheetFileNodeClass))

typedef struct _GamesCueSheetFileNode GamesCueSheetFileNode;
typedef struct _GamesCueSheetFileNodeClass GamesCueSheetFileNodeClass;
typedef struct _GamesCueSheetFileNodePrivate GamesCueSheetFileNodePrivate;

#define GAMES_TYPE_CUE_SHEET_TRACK_MODE (games_cue_sheet_track_mode_get_type ())
typedef struct _GamesCueSheetTrackNodePrivate GamesCueSheetTrackNodePrivate;

#define GAMES_TYPE_DIRECTORY (games_directory_get_type ())
#define GAMES_DIRECTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_DIRECTORY, GamesDirectory))
#define GAMES_DIRECTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_DIRECTORY, GamesDirectoryClass))
#define GAMES_IS_DIRECTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_DIRECTORY))
#define GAMES_IS_DIRECTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_DIRECTORY))
#define GAMES_DIRECTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_DIRECTORY, GamesDirectoryClass))

typedef struct _GamesDirectory GamesDirectory;
typedef struct _GamesDirectoryClass GamesDirectoryClass;
typedef struct _GamesDirectoryPrivate GamesDirectoryPrivate;

#define GAMES_TYPE_FILENAME_TITLE (games_filename_title_get_type ())
#define GAMES_FILENAME_TITLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_FILENAME_TITLE, GamesFilenameTitle))
#define GAMES_FILENAME_TITLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_FILENAME_TITLE, GamesFilenameTitleClass))
#define GAMES_IS_FILENAME_TITLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_FILENAME_TITLE))
#define GAMES_IS_FILENAME_TITLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_FILENAME_TITLE))
#define GAMES_FILENAME_TITLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_FILENAME_TITLE, GamesFilenameTitleClass))

typedef struct _GamesFilenameTitle GamesFilenameTitle;
typedef struct _GamesFilenameTitleClass GamesFilenameTitleClass;
typedef struct _GamesFilenameTitlePrivate GamesFilenameTitlePrivate;

#define GAMES_TYPE_FINGERPRINT_UID (games_fingerprint_uid_get_type ())
#define GAMES_FINGERPRINT_UID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_FINGERPRINT_UID, GamesFingerprintUid))
#define GAMES_FINGERPRINT_UID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_FINGERPRINT_UID, GamesFingerprintUidClass))
#define GAMES_IS_FINGERPRINT_UID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_FINGERPRINT_UID))
#define GAMES_IS_FINGERPRINT_UID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_FINGERPRINT_UID))
#define GAMES_FINGERPRINT_UID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_FINGERPRINT_UID, GamesFingerprintUidClass))

typedef struct _GamesFingerprintUid GamesFingerprintUid;
typedef struct _GamesFingerprintUidClass GamesFingerprintUidClass;
typedef struct _GamesFingerprintUidPrivate GamesFingerprintUidPrivate;

#define GAMES_TYPE_LOCAL_COVER (games_local_cover_get_type ())
#define GAMES_LOCAL_COVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_LOCAL_COVER, GamesLocalCover))
#define GAMES_LOCAL_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_LOCAL_COVER, GamesLocalCoverClass))
#define GAMES_IS_LOCAL_COVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_LOCAL_COVER))
#define GAMES_IS_LOCAL_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_LOCAL_COVER))
#define GAMES_LOCAL_COVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_LOCAL_COVER, GamesLocalCoverClass))

typedef struct _GamesLocalCover GamesLocalCover;
typedef struct _GamesLocalCoverClass GamesLocalCoverClass;
typedef struct _GamesLocalCoverPrivate GamesLocalCoverPrivate;

#define GAMES_TYPE_STRING_INPUT_STREAM (games_string_input_stream_get_type ())
#define GAMES_STRING_INPUT_STREAM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_STRING_INPUT_STREAM, GamesStringInputStream))
#define GAMES_STRING_INPUT_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_STRING_INPUT_STREAM, GamesStringInputStreamClass))
#define GAMES_IS_STRING_INPUT_STREAM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_STRING_INPUT_STREAM))
#define GAMES_IS_STRING_INPUT_STREAM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_STRING_INPUT_STREAM))
#define GAMES_STRING_INPUT_STREAM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_STRING_INPUT_STREAM, GamesStringInputStreamClass))

typedef struct _GamesStringInputStream GamesStringInputStream;
typedef struct _GamesStringInputStreamClass GamesStringInputStreamClass;
typedef struct _GamesStringInputStreamPrivate GamesStringInputStreamPrivate;

typedef enum  {
	GAMES_COMMAND_ERROR_INVALID_COMMAND,
	GAMES_COMMAND_ERROR_EXECUTION_FAILED
} GamesCommandError;
#define GAMES_COMMAND_ERROR games_command_error_quark ()
struct _GamesRunnerIface {
	GTypeInterface parent_iface;
	gboolean (*check_is_valid) (GamesRunner* self, gchar* * error_message, GError** error);
	GtkWidget* (*get_display) (GamesRunner* self);
	void (*start) (GamesRunner* self, GError** error);
	void (*resume) (GamesRunner* self, GError** error);
	void (*pause) (GamesRunner* self);
	void (*stop) (GamesRunner* self);
	gboolean (*get_can_fullscreen) (GamesRunner* self);
	gboolean (*get_can_quit_safely) (GamesRunner* self);
	gboolean (*get_can_resume) (GamesRunner* self);
	GamesMediaSet* (*get_media_set) (GamesRunner* self);
};

struct _GamesCommandRunner {
	GObject parent_instance;
	GamesCommandRunnerPrivate * priv;
};

struct _GamesCommandRunnerClass {
	GObjectClass parent_class;
};

struct _GamesCoverIface {
	GTypeInterface parent_iface;
	GIcon* (*get_cover) (GamesCover* self);
};

struct _GamesIconIface {
	GTypeInterface parent_iface;
	GIcon* (*get_icon) (GamesIcon* self);
};

struct _GamesGameIface {
	GTypeInterface parent_iface;
	GamesIcon* (*get_icon) (GamesGame* self);
	GamesCover* (*get_cover) (GamesGame* self);
	GamesRunner* (*get_runner) (GamesGame* self, GError** error);
	const gchar* (*get_name) (GamesGame* self);
};

typedef void (*GamesGameCallback) (GamesGame* game, void* user_data);
struct _GamesGameSourceIface {
	GTypeInterface parent_iface;
	void (*each_game) (GamesGameSource* self, GamesGameCallback callback, void* callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*each_game_finish) (GamesGameSource* self, GAsyncResult* _res_);
};

struct _GamesGameUriAdapterIface {
	GTypeInterface parent_iface;
	void (*game_for_uri) (GamesGameUriAdapter* self, const gchar* uri, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GamesGame* (*game_for_uri_finish) (GamesGameUriAdapter* self, GAsyncResult* _res_, GError** error);
};

struct _GamesInputCapabilitiesIface {
	GTypeInterface parent_iface;
	gboolean (*get_allow_classic_gamepads) (GamesInputCapabilities* self, GError** error);
	gboolean (*get_allow_analog_gamepads) (GamesInputCapabilities* self, GError** error);
};

struct _GamesMedia {
	GObject parent_instance;
	GamesMediaPrivate * priv;
};

struct _GamesMediaClass {
	GObjectClass parent_class;
};

struct _GamesTitleIface {
	GTypeInterface parent_iface;
	gchar* (*get_title) (GamesTitle* self, GError** error);
};

struct _GamesMediaSet {
	GObject parent_instance;
	GamesMediaSetPrivate * priv;
};

struct _GamesMediaSetClass {
	GObjectClass parent_class;
};

typedef void (*GamesMediaSetMediaCallback) (GamesMedia* media, void* user_data);
struct _GamesPluginIface {
	GTypeInterface parent_iface;
	GamesGameSource* (*get_game_source) (GamesPlugin* self, GError** error);
};

struct _GamesUidIface {
	GTypeInterface parent_iface;
	gchar* (*get_uid) (GamesUid* self, GError** error);
};

struct _GamesUriGameFactoryIface {
	GTypeInterface parent_iface;
	gboolean (*is_uri_valid) (GamesUriGameFactory* self, const gchar* uri);
	void (*add_uri) (GamesUriGameFactory* self, const gchar* uri);
	void (*foreach_game) (GamesUriGameFactory* self, GamesGameCallback game_callback, void* game_callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*foreach_game_finish) (GamesUriGameFactory* self, GAsyncResult* _res_);
};

struct _GamesDummyCover {
	GObject parent_instance;
	GamesDummyCoverPrivate * priv;
};

struct _GamesDummyCoverClass {
	GObjectClass parent_class;
};

struct _GamesDummyIcon {
	GObject parent_instance;
	GamesDummyIconPrivate * priv;
};

struct _GamesDummyIconClass {
	GObjectClass parent_class;
};

struct _GamesGameinfoDoc {
	GObject parent_instance;
	GamesGameinfoDocPrivate * priv;
};

struct _GamesGameinfoDocClass {
	GObjectClass parent_class;
};

struct _GamesGameinfoDiscIdDiscTitle {
	GObject parent_instance;
	GamesGameinfoDiscIdDiscTitlePrivate * priv;
};

struct _GamesGameinfoDiscIdDiscTitleClass {
	GObjectClass parent_class;
};

struct _GamesGameinfoDiscIdGameTitle {
	GObject parent_instance;
	GamesGameinfoDiscIdGameTitlePrivate * priv;
};

struct _GamesGameinfoDiscIdGameTitleClass {
	GObjectClass parent_class;
};

struct _GamesGameinfoDiscIdInputCapabilities {
	GObject parent_instance;
	GamesGameinfoDiscIdInputCapabilitiesPrivate * priv;
};

struct _GamesGameinfoDiscIdInputCapabilitiesClass {
	GObjectClass parent_class;
};

struct _GamesGenericGame {
	GObject parent_instance;
	GamesGenericGamePrivate * priv;
};

struct _GamesGenericGameClass {
	GObjectClass parent_class;
};

struct _GamesGenericSyncGameUriAdapter {
	GObject parent_instance;
	GamesGenericSyncGameUriAdapterPrivate * priv;
};

struct _GamesGenericSyncGameUriAdapterClass {
	GObjectClass parent_class;
};

typedef GamesGame* (*GamesGenericSyncGameUriAdapterGameForUri) (const gchar* uri, void* user_data, GError** error);
struct _GamesGenericTitle {
	GObject parent_instance;
	GamesGenericTitlePrivate * priv;
};

struct _GamesGenericTitleClass {
	GObjectClass parent_class;
};

struct _GamesGenericUid {
	GObject parent_instance;
	GamesGenericUidPrivate * priv;
};

struct _GamesGenericUidClass {
	GObjectClass parent_class;
};

struct _GamesGenericUriGameFactory {
	GObject parent_instance;
	GamesGenericUriGameFactoryPrivate * priv;
};

struct _GamesGenericUriGameFactoryClass {
	GObjectClass parent_class;
};

typedef gboolean (*GamesGenericUriGameFactoryUriTest) (const gchar* uri, void* user_data);
struct _GamesGriloCover {
	GObject parent_instance;
	GamesGriloCoverPrivate * priv;
};

struct _GamesGriloCoverClass {
	GObjectClass parent_class;
};

struct _GamesGriloMedia {
	GObject parent_instance;
	GamesGriloMediaPrivate * priv;
};

struct _GamesGriloMediaClass {
	GObjectClass parent_class;
};

struct _GamesRetroCoreSource {
	GObject parent_instance;
	GamesRetroCoreSourcePrivate * priv;
};

struct _GamesRetroCoreSourceClass {
	GObjectClass parent_class;
};

struct _GamesRetroRunner {
	GObject parent_instance;
	GamesRetroRunnerPrivate * priv;
};

struct _GamesRetroRunnerClass {
	GObjectClass parent_class;
};

struct _GamesTrackerQueryIface {
	GTypeInterface parent_iface;
	gboolean (*is_cursor_valid) (GamesTrackerQuery* self, TrackerSparqlCursor* cursor);
	gchar* (*get_query) (GamesTrackerQuery* self);
	void (*process_cursor) (GamesTrackerQuery* self, TrackerSparqlCursor* cursor);
	void (*foreach_game) (GamesTrackerQuery* self, GamesGameCallback game_callback, void* game_callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*foreach_game_finish) (GamesTrackerQuery* self, GAsyncResult* _res_);
};

struct _GamesMimeTypeTrackerQuery {
	GObject parent_instance;
	GamesMimeTypeTrackerQueryPrivate * priv;
};

struct _GamesMimeTypeTrackerQueryClass {
	GObjectClass parent_class;
};

struct _GamesTrackerGameSource {
	GObject parent_instance;
	GamesTrackerGameSourcePrivate * priv;
};

struct _GamesTrackerGameSourceClass {
	GObjectClass parent_class;
};

typedef enum  {
	TRACKER_ERROR_FILE_NOT_FOUND
} TrackerError;
#define TRACKER_ERROR tracker_error_quark ()
struct _GamesApplication {
	GtkApplication parent_instance;
	GamesApplicationPrivate * priv;
};

struct _GamesApplicationClass {
	GtkApplicationClass parent_class;
};

struct _GamesRemoteDisplay {
	GtkBox parent_instance;
	GamesRemoteDisplayPrivate * priv;
};

struct _GamesRemoteDisplayClass {
	GtkBoxClass parent_class;
};

struct _GamesCompositeCover {
	GObject parent_instance;
	GamesCompositeCoverPrivate * priv;
};

struct _GamesCompositeCoverClass {
	GObjectClass parent_class;
};

struct _GamesCompositeTitle {
	GObject parent_instance;
	GamesCompositeTitlePrivate * priv;
};

struct _GamesCompositeTitleClass {
	GObjectClass parent_class;
};

struct _GamesCueSheet {
	GObject parent_instance;
	GamesCueSheetPrivate * priv;
};

struct _GamesCueSheetClass {
	GObjectClass parent_class;
};

typedef enum  {
	GAMES_CUE_SHEET_FILE_FORMAT_INVALID,
	GAMES_CUE_SHEET_FILE_FORMAT_AIFF,
	GAMES_CUE_SHEET_FILE_FORMAT_BINARY,
	GAMES_CUE_SHEET_FILE_FORMAT_MOTOROLA,
	GAMES_CUE_SHEET_FILE_FORMAT_MP3,
	GAMES_CUE_SHEET_FILE_FORMAT_VORBIS,
	GAMES_CUE_SHEET_FILE_FORMAT_WAVE,
	GAMES_CUE_SHEET_FILE_FORMAT_UNKNOWN
} GamesCueSheetFileFormat;

struct _GamesCueSheetFileNode {
	GObject parent_instance;
	GamesCueSheetFileNodePrivate * priv;
};

struct _GamesCueSheetFileNodeClass {
	GObjectClass parent_class;
};

typedef enum  {
	GAMES_CUE_SHEET_TRACK_MODE_INVALID,
	GAMES_CUE_SHEET_TRACK_MODE_AUDIO,
	GAMES_CUE_SHEET_TRACK_MODE_CDG,
	GAMES_CUE_SHEET_TRACK_MODE_MODE1_2048,
	GAMES_CUE_SHEET_TRACK_MODE_MODE1_2352,
	GAMES_CUE_SHEET_TRACK_MODE_MODE2_2336,
	GAMES_CUE_SHEET_TRACK_MODE_MODE2_2352,
	GAMES_CUE_SHEET_TRACK_MODE_CDI_2336,
	GAMES_CUE_SHEET_TRACK_MODE_CDI_2352
} GamesCueSheetTrackMode;

struct _GamesCueSheetTrackNode {
	GObject parent_instance;
	GamesCueSheetTrackNodePrivate * priv;
};

struct _GamesCueSheetTrackNodeClass {
	GObjectClass parent_class;
};

struct _GamesDirectory {
	GObject parent_instance;
	GamesDirectoryPrivate * priv;
};

struct _GamesDirectoryClass {
	GObjectClass parent_class;
};

typedef gboolean (*GamesDirectoryFileInfoTest) (GFileInfo* file_info, void* user_data, GError** error);
struct _GamesFilenameTitle {
	GObject parent_instance;
	GamesFilenameTitlePrivate * priv;
};

struct _GamesFilenameTitleClass {
	GObjectClass parent_class;
};

struct _GamesFingerprintUid {
	GObject parent_instance;
	GamesFingerprintUidPrivate * priv;
};

struct _GamesFingerprintUidClass {
	GObjectClass parent_class;
};

struct _GamesLocalCover {
	GObject parent_instance;
	GamesLocalCoverPrivate * priv;
};

struct _GamesLocalCoverClass {
	GObjectClass parent_class;
};

struct _GamesStringInputStream {
	GObject parent_instance;
	GamesStringInputStreamPrivate * priv;
};

struct _GamesStringInputStreamClass {
	GObjectClass parent_class;
};


GQuark games_command_error_quark (void);
GType games_media_set_get_type (void) G_GNUC_CONST;
GType games_runner_get_type (void) G_GNUC_CONST;
GType games_command_runner_get_type (void) G_GNUC_CONST;
GamesCommandRunner* games_command_runner_new (gchar** args, int args_length1, gboolean watch_child);
GamesCommandRunner* games_command_runner_construct (GType object_type, gchar** args, int args_length1, gboolean watch_child);
GType games_cover_get_type (void) G_GNUC_CONST;
GIcon* games_cover_get_cover (GamesCover* self);
GType games_icon_get_type (void) G_GNUC_CONST;
GType games_game_get_type (void) G_GNUC_CONST;
GamesIcon* games_game_get_icon (GamesGame* self);
GamesCover* games_game_get_cover (GamesGame* self);
GamesRunner* games_game_get_runner (GamesGame* self, GError** error);
const gchar* games_game_get_name (GamesGame* self);
GType games_game_source_get_type (void) G_GNUC_CONST;
void games_game_source_each_game (GamesGameSource* self, GamesGameCallback callback, void* callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
void games_game_source_each_game_finish (GamesGameSource* self, GAsyncResult* _res_);
GType games_game_uri_adapter_get_type (void) G_GNUC_CONST;
void games_game_uri_adapter_game_for_uri (GamesGameUriAdapter* self, const gchar* uri, GAsyncReadyCallback _callback_, gpointer _user_data_);
GamesGame* games_game_uri_adapter_game_for_uri_finish (GamesGameUriAdapter* self, GAsyncResult* _res_, GError** error);
GIcon* games_icon_get_icon (GamesIcon* self);
GType games_input_capabilities_get_type (void) G_GNUC_CONST;
gboolean games_input_capabilities_get_allow_classic_gamepads (GamesInputCapabilities* self, GError** error);
gboolean games_input_capabilities_get_allow_analog_gamepads (GamesInputCapabilities* self, GError** error);
GType games_media_get_type (void) G_GNUC_CONST;
GType games_title_get_type (void) G_GNUC_CONST;
GamesMedia* games_media_new (const gchar* uri, GamesTitle* title);
GamesMedia* games_media_construct (GType object_type, const gchar* uri, GamesTitle* title);
GamesTitle* games_media_get_title (GamesMedia* self);
const gchar* games_media_get_uri (GamesMedia* self);
GamesMediaSet* games_media_set_new (GamesMedia** medias, int medias_length1, GIcon* icon);
GamesMediaSet* games_media_set_construct (GType object_type, GamesMedia** medias, int medias_length1, GIcon* icon);
gint games_media_set_get_size (GamesMediaSet* self);
GamesMedia* games_media_set_get_selected_media (GamesMediaSet* self, guint index, GError** error);
void games_media_set_foreach_media (GamesMediaSet* self, GamesMediaSetMediaCallback media_callback, void* media_callback_target);
gint games_media_set_get_selected_media_number (GamesMediaSet* self);
void games_media_set_set_selected_media_number (GamesMediaSet* self, gint value);
GIcon* games_media_set_get_icon (GamesMediaSet* self);
GType games_plugin_get_type (void) G_GNUC_CONST;
GamesGameSource* games_plugin_get_game_source (GamesPlugin* self, GError** error);
gboolean games_runner_check_is_valid (GamesRunner* self, gchar* * error_message, GError** error);
GtkWidget* games_runner_get_display (GamesRunner* self);
void games_runner_start (GamesRunner* self, GError** error);
void games_runner_resume (GamesRunner* self, GError** error);
void games_runner_pause (GamesRunner* self);
void games_runner_stop (GamesRunner* self);
gboolean games_runner_get_can_fullscreen (GamesRunner* self);
gboolean games_runner_get_can_quit_safely (GamesRunner* self);
gboolean games_runner_get_can_resume (GamesRunner* self);
GamesMediaSet* games_runner_get_media_set (GamesRunner* self);
gchar* games_title_get_title (GamesTitle* self, GError** error);
GType games_uid_get_type (void) G_GNUC_CONST;
gchar* games_uid_get_uid (GamesUid* self, GError** error);
GType games_uri_game_factory_get_type (void) G_GNUC_CONST;
gboolean games_uri_game_factory_is_uri_valid (GamesUriGameFactory* self, const gchar* uri);
void games_uri_game_factory_add_uri (GamesUriGameFactory* self, const gchar* uri);
void games_uri_game_factory_foreach_game (GamesUriGameFactory* self, GamesGameCallback game_callback, void* game_callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
void games_uri_game_factory_foreach_game_finish (GamesUriGameFactory* self, GAsyncResult* _res_);
GType games_dummy_cover_get_type (void) G_GNUC_CONST;
GamesDummyCover* games_dummy_cover_new (void);
GamesDummyCover* games_dummy_cover_construct (GType object_type);
GType games_dummy_icon_get_type (void) G_GNUC_CONST;
GamesDummyIcon* games_dummy_icon_new (void);
GamesDummyIcon* games_dummy_icon_construct (GType object_type);
GType games_gameinfo_doc_get_type (void) G_GNUC_CONST;
GamesGameinfoDoc* games_gameinfo_doc_new_from_data (guint8* data, int data_length1, GError** error);
GamesGameinfoDoc* games_gameinfo_doc_construct_from_data (GType object_type, guint8* data, int data_length1, GError** error);
gchar* games_gameinfo_doc_get_game_title_for_disc_id (GamesGameinfoDoc* self, const gchar* disc_id, GError** error);
gchar** games_gameinfo_doc_get_game_controllers_for_disc_id (GamesGameinfoDoc* self, const gchar* disc_id, int* result_length1, GError** error);
gchar* games_gameinfo_doc_get_disc_title_for_disc_id (GamesGameinfoDoc* self, const gchar* disc_id, GError** error);
gchar* games_gameinfo_doc_get_disc_set_id_for_disc_id (GamesGameinfoDoc* self, const gchar* disc_id, GError** error);
gint games_gameinfo_doc_get_disc_set_index_for_disc_id (GamesGameinfoDoc* self, const gchar* disc_id, GError** error);
gint games_gameinfo_doc_get_disc_set_size_for_disc_id (GamesGameinfoDoc* self, const gchar* disc_id, GError** error);
GamesGameinfoDoc* games_gameinfo_doc_new (void);
GamesGameinfoDoc* games_gameinfo_doc_construct (GType object_type);
GType games_gameinfo_disc_id_disc_title_get_type (void) G_GNUC_CONST;
GamesGameinfoDiscIdDiscTitle* games_gameinfo_disc_id_disc_title_new (GamesGameinfoDoc* gameinfo, const gchar* disc_id, const gchar* domain);
GamesGameinfoDiscIdDiscTitle* games_gameinfo_disc_id_disc_title_construct (GType object_type, GamesGameinfoDoc* gameinfo, const gchar* disc_id, const gchar* domain);
GType games_gameinfo_disc_id_game_title_get_type (void) G_GNUC_CONST;
GamesGameinfoDiscIdGameTitle* games_gameinfo_disc_id_game_title_new (GamesGameinfoDoc* gameinfo, const gchar* disc_id, const gchar* domain);
GamesGameinfoDiscIdGameTitle* games_gameinfo_disc_id_game_title_construct (GType object_type, GamesGameinfoDoc* gameinfo, const gchar* disc_id, const gchar* domain);
GType games_gameinfo_disc_id_input_capabilities_get_type (void) G_GNUC_CONST;
GamesGameinfoDiscIdInputCapabilities* games_gameinfo_disc_id_input_capabilities_new (GamesGameinfoDoc* gameinfo, const gchar* disc_id);
GamesGameinfoDiscIdInputCapabilities* games_gameinfo_disc_id_input_capabilities_construct (GType object_type, GamesGameinfoDoc* gameinfo, const gchar* disc_id);
gboolean games_gameinfo_disc_id_input_capabilities_get_default_allow_classic_gamepads (GamesGameinfoDiscIdInputCapabilities* self);
void games_gameinfo_disc_id_input_capabilities_set_default_allow_classic_gamepads (GamesGameinfoDiscIdInputCapabilities* self, gboolean value);
gboolean games_gameinfo_disc_id_input_capabilities_get_default_allow_analog_gamepads (GamesGameinfoDiscIdInputCapabilities* self);
void games_gameinfo_disc_id_input_capabilities_set_default_allow_analog_gamepads (GamesGameinfoDiscIdInputCapabilities* self, gboolean value);
GType games_generic_game_get_type (void) G_GNUC_CONST;
GamesGenericGame* games_generic_game_new (GamesTitle* title, GamesIcon* icon, GamesCover* cover, GamesRunner* runner);
GamesGenericGame* games_generic_game_construct (GType object_type, GamesTitle* title, GamesIcon* icon, GamesCover* cover, GamesRunner* runner);
GType games_generic_sync_game_uri_adapter_get_type (void) G_GNUC_CONST;
GamesGenericSyncGameUriAdapter* games_generic_sync_game_uri_adapter_new (GamesGenericSyncGameUriAdapterGameForUri callback, void* callback_target, GDestroyNotify callback_target_destroy_notify);
GamesGenericSyncGameUriAdapter* games_generic_sync_game_uri_adapter_construct (GType object_type, GamesGenericSyncGameUriAdapterGameForUri callback, void* callback_target, GDestroyNotify callback_target_destroy_notify);
GType games_generic_title_get_type (void) G_GNUC_CONST;
GamesGenericTitle* games_generic_title_new (const gchar* title);
GamesGenericTitle* games_generic_title_construct (GType object_type, const gchar* title);
GType games_generic_uid_get_type (void) G_GNUC_CONST;
GamesGenericUid* games_generic_uid_new (const gchar* uid);
GamesGenericUid* games_generic_uid_construct (GType object_type, const gchar* uid);
GType games_generic_uri_game_factory_get_type (void) G_GNUC_CONST;
GamesGenericUriGameFactory* games_generic_uri_game_factory_new (GamesGameUriAdapter* game_uri_adapter, GamesGenericUriGameFactoryUriTest uri_validity_test, void* uri_validity_test_target, GDestroyNotify uri_validity_test_target_destroy_notify);
GamesGenericUriGameFactory* games_generic_uri_game_factory_construct (GType object_type, GamesGameUriAdapter* game_uri_adapter, GamesGenericUriGameFactoryUriTest uri_validity_test, void* uri_validity_test_target, GDestroyNotify uri_validity_test_target_destroy_notify);
GType games_grilo_cover_get_type (void) G_GNUC_CONST;
GType games_grilo_media_get_type (void) G_GNUC_CONST;
GamesGriloCover* games_grilo_cover_new (GamesGriloMedia* media, GamesUid* uid);
GamesGriloCover* games_grilo_cover_construct (GType object_type, GamesGriloMedia* media, GamesUid* uid);
GamesGriloMedia* games_grilo_media_new (GamesTitle* title, const gchar* mime_type);
GamesGriloMedia* games_grilo_media_construct (GType object_type, GamesTitle* title, const gchar* mime_type);
void games_grilo_media_try_resolve_media (GamesGriloMedia* self);
GType games_retro_core_source_get_type (void) G_GNUC_CONST;
GamesRetroCoreSource* games_retro_core_source_new (const gchar* platform, gchar** mime_types, int mime_types_length1);
GamesRetroCoreSource* games_retro_core_source_construct (GType object_type, const gchar* platform, gchar** mime_types, int mime_types_length1);
gchar* games_retro_core_source_get_platform (GamesRetroCoreSource* self);
gchar* games_retro_core_source_get_module_path (GamesRetroCoreSource* self, GError** error);
GType games_retro_runner_get_type (void) G_GNUC_CONST;
GamesRetroRunner* games_retro_runner_new (GamesRetroCoreSource* core_source, const gchar* uri, GamesUid* uid, GamesTitle* game_title);
GamesRetroRunner* games_retro_runner_construct (GType object_type, GamesRetroCoreSource* core_source, const gchar* uri, GamesUid* uid, GamesTitle* game_title);
GamesRetroRunner* games_retro_runner_new_for_media_set_and_input_capabilities (GamesRetroCoreSource* core_source, GamesMediaSet* media_set, GamesUid* uid, GamesInputCapabilities* input_capabilities, GamesTitle* game_title);
GamesRetroRunner* games_retro_runner_construct_for_media_set_and_input_capabilities (GType object_type, GamesRetroCoreSource* core_source, GamesMediaSet* media_set, GamesUid* uid, GamesInputCapabilities* input_capabilities, GamesTitle* game_title);
GamesRetroRunner* games_retro_runner_new_for_core_descriptor (RetroCoreDescriptor* core_descriptor, GamesUid* uid, GamesTitle* game_title);
GamesRetroRunner* games_retro_runner_construct_for_core_descriptor (GType object_type, RetroCoreDescriptor* core_descriptor, GamesUid* uid, GamesTitle* game_title);
GType games_tracker_query_get_type (void) G_GNUC_CONST;
GType games_mime_type_tracker_query_get_type (void) G_GNUC_CONST;
GamesMimeTypeTrackerQuery* games_mime_type_tracker_query_new (const gchar* mime_type, GamesUriGameFactory* uri_game_factory);
GamesMimeTypeTrackerQuery* games_mime_type_tracker_query_construct (GType object_type, const gchar* mime_type, GamesUriGameFactory* uri_game_factory);
GType games_tracker_game_source_get_type (void) G_GNUC_CONST;
GamesTrackerGameSource* games_tracker_game_source_new (TrackerSparqlConnection* connection);
GamesTrackerGameSource* games_tracker_game_source_construct (GType object_type, TrackerSparqlConnection* connection);
void games_tracker_game_source_add_query (GamesTrackerGameSource* self, GamesTrackerQuery* query);
void games_tracker_game_source_each_game_for_query (GamesTrackerGameSource* self, GamesGameCallback game_callback, void* game_callback_target, GamesTrackerQuery* query, GAsyncReadyCallback _callback_, gpointer _user_data_);
void games_tracker_game_source_each_game_for_query_finish (GamesTrackerGameSource* self, GAsyncResult* _res_);
GQuark tracker_error_quark (void);
gboolean games_tracker_query_is_cursor_valid (GamesTrackerQuery* self, TrackerSparqlCursor* cursor);
gchar* games_tracker_query_get_query (GamesTrackerQuery* self);
void games_tracker_query_process_cursor (GamesTrackerQuery* self, TrackerSparqlCursor* cursor);
void games_tracker_query_foreach_game (GamesTrackerQuery* self, GamesGameCallback game_callback, void* game_callback_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
void games_tracker_query_foreach_game_finish (GamesTrackerQuery* self, GAsyncResult* _res_);
GType games_application_get_type (void) G_GNUC_CONST;
gchar* games_application_get_data_dir (void);
gchar* games_application_get_saves_dir (void);
gchar* games_application_get_snapshots_dir (void);
gchar* games_application_get_cache_dir (void);
gchar* games_application_get_config_dir (void);
gchar* games_application_get_platforms_dir (void);
gchar* games_application_get_covers_dir (void);
void games_application_try_make_dir (const gchar* path);
gchar* games_application_get_medias_dir (void);
GType games_remote_display_get_type (void) G_GNUC_CONST;
GamesRemoteDisplay* games_remote_display_new (void);
GamesRemoteDisplay* games_remote_display_construct (GType object_type);
GType games_composite_cover_get_type (void) G_GNUC_CONST;
GamesCompositeCover* games_composite_cover_new (GamesCover** covers, int covers_length1);
GamesCompositeCover* games_composite_cover_construct (GType object_type, GamesCover** covers, int covers_length1);
GType games_composite_title_get_type (void) G_GNUC_CONST;
GamesCompositeTitle* games_composite_title_new (GamesTitle** titles, int titles_length1);
GamesCompositeTitle* games_composite_title_construct (GType object_type, GamesTitle** titles, int titles_length1);
GType games_cue_sheet_get_type (void) G_GNUC_CONST;
GamesCueSheet* games_cue_sheet_new (GFile* file, GError** error);
GamesCueSheet* games_cue_sheet_construct (GType object_type, GFile* file, GError** error);
GType games_cue_sheet_track_node_get_type (void) G_GNUC_CONST;
GamesCueSheetTrackNode* games_cue_sheet_get_track (GamesCueSheet* self, guint i, GError** error);
GFile* games_cue_sheet_get_file (GamesCueSheet* self);
guint games_cue_sheet_get_tracks_number (GamesCueSheet* self);
GType games_cue_sheet_file_format_get_type (void) G_GNUC_CONST;
GamesCueSheetFileFormat games_cue_sheet_file_format_parse_string (const gchar* value);
GType games_cue_sheet_file_node_get_type (void) G_GNUC_CONST;
GamesCueSheetFileNode* games_cue_sheet_file_node_new (GFile* file, GamesCueSheetFileFormat file_format);
GamesCueSheetFileNode* games_cue_sheet_file_node_construct (GType object_type, GFile* file, GamesCueSheetFileFormat file_format);
const gchar* games_cue_sheet_file_node_get_file_name (GamesCueSheetFileNode* self);
GamesCueSheetFileFormat games_cue_sheet_file_node_get_file_format (GamesCueSheetFileNode* self);
GFile* games_cue_sheet_file_node_get_file (GamesCueSheetFileNode* self);
GType games_cue_sheet_track_mode_get_type (void) G_GNUC_CONST;
GamesCueSheetTrackMode games_cue_sheet_track_mode_parse_string (const gchar* value);
gboolean games_cue_sheet_track_mode_is_mode1 (GamesCueSheetTrackMode self);
GamesCueSheetTrackNode* games_cue_sheet_track_node_new (GamesCueSheetFileNode* file, gint track_number, GamesCueSheetTrackMode track_mode);
GamesCueSheetTrackNode* games_cue_sheet_track_node_construct (GType object_type, GamesCueSheetFileNode* file, gint track_number, GamesCueSheetTrackMode track_mode);
GamesCueSheetFileNode* games_cue_sheet_track_node_get_file (GamesCueSheetTrackNode* self);
gint games_cue_sheet_track_node_get_track_number (GamesCueSheetTrackNode* self);
GamesCueSheetTrackMode games_cue_sheet_track_node_get_track_mode (GamesCueSheetTrackNode* self);
GType games_directory_get_type (void) G_GNUC_CONST;
GamesDirectory* games_directory_new (GFile* file);
GamesDirectory* games_directory_construct (GType object_type, GFile* file);
void games_directory_foreach (GamesDirectory* self, const gchar* attributes, GamesDirectoryFileInfoTest file_info_test, void* file_info_test_target, GError** error);
GType games_filename_title_get_type (void) G_GNUC_CONST;
GamesFilenameTitle* games_filename_title_new (const gchar* uri);
GamesFilenameTitle* games_filename_title_construct (GType object_type, const gchar* uri);
GType games_fingerprint_uid_get_type (void) G_GNUC_CONST;
GamesFingerprintUid* games_fingerprint_uid_new (const gchar* uri, const gchar* prefix);
GamesFingerprintUid* games_fingerprint_uid_construct (GType object_type, const gchar* uri, const gchar* prefix);
GamesFingerprintUid* games_fingerprint_uid_new_for_chunk (const gchar* uri, const gchar* prefix, gsize start, gsize length);
GamesFingerprintUid* games_fingerprint_uid_construct_for_chunk (GType object_type, const gchar* uri, const gchar* prefix, gsize start, gsize length);
gsize* games_grep_get_offsets (const gchar* filename, const gchar* text, int* result_length1);
GType games_local_cover_get_type (void) G_GNUC_CONST;
GamesLocalCover* games_local_cover_new (const gchar* uri);
GamesLocalCover* games_local_cover_construct (GType object_type, const gchar* uri);
GType games_string_input_stream_get_type (void) G_GNUC_CONST;
GamesStringInputStream* games_string_input_stream_new (GFile* file);
GamesStringInputStream* games_string_input_stream_construct (GType object_type, GFile* file);
gboolean games_string_input_stream_has_string (GamesStringInputStream* self, gsize offset, const gchar* value, GError** error);
gchar* games_string_input_stream_read_string (GamesStringInputStream* self, gsize offset, GError** error);
gchar* games_string_input_stream_read_string_for_size (GamesStringInputStream* self, gsize offset, gsize size, GError** error);


G_END_DECLS

#endif
