/* quit-dialog.c generated by valac 0.35.5, the Vala compiler
 * generated from quit-dialog.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>


#define GAMES_TYPE_QUIT_DIALOG (games_quit_dialog_get_type ())
#define GAMES_QUIT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_QUIT_DIALOG, GamesQuitDialog))
#define GAMES_QUIT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_QUIT_DIALOG, GamesQuitDialogClass))
#define GAMES_IS_QUIT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_QUIT_DIALOG))
#define GAMES_IS_QUIT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_QUIT_DIALOG))
#define GAMES_QUIT_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_QUIT_DIALOG, GamesQuitDialogClass))

typedef struct _GamesQuitDialog GamesQuitDialog;
typedef struct _GamesQuitDialogClass GamesQuitDialogClass;
typedef struct _GamesQuitDialogPrivate GamesQuitDialogPrivate;

struct _GamesQuitDialog {
	GtkDialog parent_instance;
	GamesQuitDialogPrivate * priv;
};

struct _GamesQuitDialogClass {
	GtkDialogClass parent_class;
};


static gpointer games_quit_dialog_parent_class = NULL;

GType games_quit_dialog_get_type (void) G_GNUC_CONST;
enum  {
	GAMES_QUIT_DIALOG_DUMMY_PROPERTY
};
GamesQuitDialog* games_quit_dialog_new (void);
GamesQuitDialog* games_quit_dialog_construct (GType object_type);
static GObject * games_quit_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);


GamesQuitDialog* games_quit_dialog_construct (GType object_type) {
	GamesQuitDialog * self = NULL;
	self = (GamesQuitDialog*) g_object_new (object_type, NULL);
	return self;
}


GamesQuitDialog* games_quit_dialog_new (void) {
	return games_quit_dialog_construct (GAMES_TYPE_QUIT_DIALOG);
}


static GObject * games_quit_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GamesQuitDialog * self;
	parent_class = G_OBJECT_CLASS (games_quit_dialog_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GAMES_TYPE_QUIT_DIALOG, GamesQuitDialog);
	g_object_set ((GtkDialog*) self, "use-header-bar", 1, NULL);
	return obj;
}


static void games_quit_dialog_class_init (GamesQuitDialogClass * klass) {
	games_quit_dialog_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->constructor = games_quit_dialog_constructor;
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Games/ui/quit-dialog.ui");
}


static void games_quit_dialog_instance_init (GamesQuitDialog * self) {
	gtk_widget_init_template (GTK_WIDGET (self));
}


GType games_quit_dialog_get_type (void) {
	static volatile gsize games_quit_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&games_quit_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesQuitDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) games_quit_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GamesQuitDialog), 0, (GInstanceInitFunc) games_quit_dialog_instance_init, NULL };
		GType games_quit_dialog_type_id;
		games_quit_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "GamesQuitDialog", &g_define_type_info, 0);
		g_once_init_leave (&games_quit_dialog_type_id__volatile, games_quit_dialog_type_id);
	}
	return games_quit_dialog_type_id__volatile;
}



