/* desktop-error.c generated by valac 0.35.5, the Vala compiler
 * generated from desktop-error.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>


typedef enum  {
	GAMES_DESKTOP_ERROR_INVALID_APPINFO,
	GAMES_DESKTOP_ERROR_BLACKLISTED_GAME
} GamesDesktopError;
#define GAMES_DESKTOP_ERROR games_desktop_error_quark ()


GQuark games_desktop_error_quark (void);


GQuark games_desktop_error_quark (void) {
	return g_quark_from_static_string ("games_desktop_error-quark");
}



