/* main.c generated by valac 0.35.5, the Vala compiler
 * generated from main.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <grilo.h>
#include <gtk/gtk.h>
#include <gio/gio.h>


#define GAMES_TYPE_APPLICATION (games_application_get_type ())
#define GAMES_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_APPLICATION, GamesApplication))
#define GAMES_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_APPLICATION, GamesApplicationClass))
#define GAMES_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_APPLICATION))
#define GAMES_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_APPLICATION))
#define GAMES_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_APPLICATION, GamesApplicationClass))

typedef struct _GamesApplication GamesApplication;
typedef struct _GamesApplicationClass GamesApplicationClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))



gint _vala_main (gchar** args, int args_length1);
GType games_application_get_type (void) G_GNUC_CONST;
GamesApplication* games_application_new (void);
GamesApplication* games_application_construct (GType object_type);


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	GamesApplication* app;
	GamesApplication* _tmp0_;
	gint _result_;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_;
	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
	textdomain (GETTEXT_PACKAGE);
	grl_init (&args_length1, &args);
	_tmp0_ = games_application_new ();
	app = _tmp0_;
	_tmp1_ = args;
	_tmp1__length1 = args_length1;
	_tmp2_ = g_application_run ((GApplication*) app, _tmp1__length1, _tmp1_);
	_result_ = _tmp2_;
	grl_deinit ();
	result = _result_;
	_g_object_unref0 (app);
	return result;
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
	return _vala_main (argv, argc);
}



