/* preferences-page-plugins-item.c generated by valac 0.35.5, the Vala compiler
 * generated from preferences-page-plugins-item.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>


#define GAMES_TYPE_PREFERENCES_PAGE_PLUGINS_ITEM (games_preferences_page_plugins_item_get_type ())
#define GAMES_PREFERENCES_PAGE_PLUGINS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_PREFERENCES_PAGE_PLUGINS_ITEM, GamesPreferencesPagePluginsItem))
#define GAMES_PREFERENCES_PAGE_PLUGINS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_PREFERENCES_PAGE_PLUGINS_ITEM, GamesPreferencesPagePluginsItemClass))
#define GAMES_IS_PREFERENCES_PAGE_PLUGINS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_PREFERENCES_PAGE_PLUGINS_ITEM))
#define GAMES_IS_PREFERENCES_PAGE_PLUGINS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_PREFERENCES_PAGE_PLUGINS_ITEM))
#define GAMES_PREFERENCES_PAGE_PLUGINS_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_PREFERENCES_PAGE_PLUGINS_ITEM, GamesPreferencesPagePluginsItemClass))

typedef struct _GamesPreferencesPagePluginsItem GamesPreferencesPagePluginsItem;
typedef struct _GamesPreferencesPagePluginsItemClass GamesPreferencesPagePluginsItemClass;
typedef struct _GamesPreferencesPagePluginsItemPrivate GamesPreferencesPagePluginsItemPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GAMES_TYPE_PLUGIN_REGISTRAR (games_plugin_registrar_get_type ())
#define GAMES_PLUGIN_REGISTRAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_TYPE_PLUGIN_REGISTRAR, GamesPluginRegistrar))
#define GAMES_PLUGIN_REGISTRAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_TYPE_PLUGIN_REGISTRAR, GamesPluginRegistrarClass))
#define GAMES_IS_PLUGIN_REGISTRAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_TYPE_PLUGIN_REGISTRAR))
#define GAMES_IS_PLUGIN_REGISTRAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_TYPE_PLUGIN_REGISTRAR))
#define GAMES_PLUGIN_REGISTRAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_TYPE_PLUGIN_REGISTRAR, GamesPluginRegistrarClass))

typedef struct _GamesPluginRegistrar GamesPluginRegistrar;
typedef struct _GamesPluginRegistrarClass GamesPluginRegistrarClass;

struct _GamesPreferencesPagePluginsItem {
	GtkBox parent_instance;
	GamesPreferencesPagePluginsItemPrivate * priv;
};

struct _GamesPreferencesPagePluginsItemClass {
	GtkBoxClass parent_class;
};

struct _GamesPreferencesPagePluginsItemPrivate {
	GtkLabel* plugin_name;
	GtkLabel* plugin_description;
};


static gpointer games_preferences_page_plugins_item_parent_class = NULL;

GType games_preferences_page_plugins_item_get_type (void) G_GNUC_CONST;
#define GAMES_PREFERENCES_PAGE_PLUGINS_ITEM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GAMES_TYPE_PREFERENCES_PAGE_PLUGINS_ITEM, GamesPreferencesPagePluginsItemPrivate))
enum  {
	GAMES_PREFERENCES_PAGE_PLUGINS_ITEM_DUMMY_PROPERTY
};
GType games_plugin_registrar_get_type (void) G_GNUC_CONST;
GamesPreferencesPagePluginsItem* games_preferences_page_plugins_item_new (GamesPluginRegistrar* plugin_registrar);
GamesPreferencesPagePluginsItem* games_preferences_page_plugins_item_construct (GType object_type, GamesPluginRegistrar* plugin_registrar);
const gchar* games_plugin_registrar_get_name (GamesPluginRegistrar* self);
const gchar* games_plugin_registrar_get_description (GamesPluginRegistrar* self);
static void games_preferences_page_plugins_item_finalize (GObject * obj);


GamesPreferencesPagePluginsItem* games_preferences_page_plugins_item_construct (GType object_type, GamesPluginRegistrar* plugin_registrar) {
	GamesPreferencesPagePluginsItem * self = NULL;
	GtkLabel* _tmp0_;
	GamesPluginRegistrar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	GtkLabel* _tmp4_;
	GamesPluginRegistrar* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	g_return_val_if_fail (plugin_registrar != NULL, NULL);
	self = (GamesPreferencesPagePluginsItem*) g_object_new (object_type, NULL);
	_tmp0_ = self->priv->plugin_name;
	_tmp1_ = plugin_registrar;
	_tmp2_ = games_plugin_registrar_get_name (_tmp1_);
	_tmp3_ = _tmp2_;
	gtk_label_set_label (_tmp0_, _tmp3_);
	_tmp4_ = self->priv->plugin_description;
	_tmp5_ = plugin_registrar;
	_tmp6_ = games_plugin_registrar_get_description (_tmp5_);
	_tmp7_ = _tmp6_;
	gtk_label_set_label (_tmp4_, _tmp7_);
	return self;
}


GamesPreferencesPagePluginsItem* games_preferences_page_plugins_item_new (GamesPluginRegistrar* plugin_registrar) {
	return games_preferences_page_plugins_item_construct (GAMES_TYPE_PREFERENCES_PAGE_PLUGINS_ITEM, plugin_registrar);
}


static void games_preferences_page_plugins_item_class_init (GamesPreferencesPagePluginsItemClass * klass) {
	gint GamesPreferencesPagePluginsItem_private_offset;
	games_preferences_page_plugins_item_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (GamesPreferencesPagePluginsItemPrivate));
	G_OBJECT_CLASS (klass)->finalize = games_preferences_page_plugins_item_finalize;
	GamesPreferencesPagePluginsItem_private_offset = g_type_class_get_instance_private_offset (klass);
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Games/ui/preferences-page-plugins-item.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "plugin_name", FALSE, GamesPreferencesPagePluginsItem_private_offset + G_STRUCT_OFFSET (GamesPreferencesPagePluginsItemPrivate, plugin_name));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "plugin_description", FALSE, GamesPreferencesPagePluginsItem_private_offset + G_STRUCT_OFFSET (GamesPreferencesPagePluginsItemPrivate, plugin_description));
}


static void games_preferences_page_plugins_item_instance_init (GamesPreferencesPagePluginsItem * self) {
	self->priv = GAMES_PREFERENCES_PAGE_PLUGINS_ITEM_GET_PRIVATE (self);
	gtk_widget_init_template (GTK_WIDGET (self));
}


static void games_preferences_page_plugins_item_finalize (GObject * obj) {
	GamesPreferencesPagePluginsItem * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GAMES_TYPE_PREFERENCES_PAGE_PLUGINS_ITEM, GamesPreferencesPagePluginsItem);
	_g_object_unref0 (self->priv->plugin_name);
	_g_object_unref0 (self->priv->plugin_description);
	G_OBJECT_CLASS (games_preferences_page_plugins_item_parent_class)->finalize (obj);
}


GType games_preferences_page_plugins_item_get_type (void) {
	static volatile gsize games_preferences_page_plugins_item_type_id__volatile = 0;
	if (g_once_init_enter (&games_preferences_page_plugins_item_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesPreferencesPagePluginsItemClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) games_preferences_page_plugins_item_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GamesPreferencesPagePluginsItem), 0, (GInstanceInitFunc) games_preferences_page_plugins_item_instance_init, NULL };
		GType games_preferences_page_plugins_item_type_id;
		games_preferences_page_plugins_item_type_id = g_type_register_static (gtk_box_get_type (), "GamesPreferencesPagePluginsItem", &g_define_type_info, 0);
		g_once_init_leave (&games_preferences_page_plugins_item_type_id__volatile, games_preferences_page_plugins_item_type_id);
	}
	return games_preferences_page_plugins_item_type_id__volatile;
}



