/* retro-platform.c generated by valac 0.35.5, the Vala compiler
 * generated from retro-platform.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>




gchar* games_retro_platform_get_platform_name (const gchar* platform);


gchar* games_retro_platform_get_platform_name (const gchar* platform) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GQuark _tmp3_ = 0U;
	static GQuark _tmp2_label0 = 0;
	static GQuark _tmp2_label1 = 0;
	static GQuark _tmp2_label2 = 0;
	static GQuark _tmp2_label3 = 0;
	static GQuark _tmp2_label4 = 0;
	static GQuark _tmp2_label5 = 0;
	static GQuark _tmp2_label6 = 0;
	static GQuark _tmp2_label7 = 0;
	static GQuark _tmp2_label8 = 0;
	static GQuark _tmp2_label9 = 0;
	static GQuark _tmp2_label10 = 0;
	static GQuark _tmp2_label11 = 0;
	static GQuark _tmp2_label12 = 0;
	static GQuark _tmp2_label13 = 0;
	static GQuark _tmp2_label14 = 0;
	static GQuark _tmp2_label15 = 0;
	static GQuark _tmp2_label16 = 0;
	static GQuark _tmp2_label17 = 0;
	static GQuark _tmp2_label18 = 0;
	static GQuark _tmp2_label19 = 0;
	static GQuark _tmp2_label20 = 0;
	static GQuark _tmp2_label21 = 0;
	static GQuark _tmp2_label22 = 0;
	static GQuark _tmp2_label23 = 0;
	static GQuark _tmp2_label24 = 0;
	static GQuark _tmp2_label25 = 0;
	static GQuark _tmp2_label26 = 0;
	static GQuark _tmp2_label27 = 0;
	static GQuark _tmp2_label28 = 0;
	static GQuark _tmp2_label29 = 0;
	static GQuark _tmp2_label30 = 0;
	static GQuark _tmp2_label31 = 0;
	static GQuark _tmp2_label32 = 0;
	static GQuark _tmp2_label33 = 0;
	static GQuark _tmp2_label34 = 0;
	static GQuark _tmp2_label35 = 0;
	static GQuark _tmp2_label36 = 0;
	static GQuark _tmp2_label37 = 0;
	g_return_val_if_fail (platform != NULL, NULL);
	_tmp0_ = platform;
	_tmp1_ = _tmp0_;
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
	if (_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string ("Amiga")))) {
		switch (0) {
			default:
			{
				gchar* _tmp4_;
				_tmp4_ = g_strdup (_ ("Amiga"));
				result = _tmp4_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string ("Atari2600")))) {
		switch (0) {
			default:
			{
				gchar* _tmp5_;
				_tmp5_ = g_strdup (_ ("Atari 2600"));
				result = _tmp5_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string ("Atari5200")))) {
		switch (0) {
			default:
			{
				gchar* _tmp6_;
				_tmp6_ = g_strdup (_ ("Atari 5200"));
				result = _tmp6_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label3) ? _tmp2_label3 : (_tmp2_label3 = g_quark_from_static_string ("Atari7800")))) {
		switch (0) {
			default:
			{
				gchar* _tmp7_;
				_tmp7_ = g_strdup (_ ("Atari 7800"));
				result = _tmp7_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label4) ? _tmp2_label4 : (_tmp2_label4 = g_quark_from_static_string ("DOOM")))) {
		switch (0) {
			default:
			{
				gchar* _tmp8_;
				_tmp8_ = g_strdup (_ ("DOOM"));
				result = _tmp8_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label5) ? _tmp2_label5 : (_tmp2_label5 = g_quark_from_static_string ("Dreamcast")))) {
		switch (0) {
			default:
			{
				gchar* _tmp9_;
				_tmp9_ = g_strdup (_ ("Dreamcast"));
				result = _tmp9_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label6) ? _tmp2_label6 : (_tmp2_label6 = g_quark_from_static_string ("FamicomDiskSystem")))) {
		switch (0) {
			default:
			{
				gchar* _tmp10_;
				_tmp10_ = g_strdup (_ ("Famicom Disk System"));
				result = _tmp10_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label7) ? _tmp2_label7 : (_tmp2_label7 = g_quark_from_static_string ("GameBoy")))) {
		switch (0) {
			default:
			{
				gchar* _tmp11_;
				_tmp11_ = g_strdup (_ ("Game Boy"));
				result = _tmp11_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label8) ? _tmp2_label8 : (_tmp2_label8 = g_quark_from_static_string ("GameBoyColor")))) {
		switch (0) {
			default:
			{
				gchar* _tmp12_;
				_tmp12_ = g_strdup (_ ("Game Boy Color"));
				result = _tmp12_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label9) ? _tmp2_label9 : (_tmp2_label9 = g_quark_from_static_string ("GameBoyAdvance")))) {
		switch (0) {
			default:
			{
				gchar* _tmp13_;
				_tmp13_ = g_strdup (_ ("Game Boy Advance"));
				result = _tmp13_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label10) ? _tmp2_label10 : (_tmp2_label10 = g_quark_from_static_string ("GameCube")))) {
		switch (0) {
			default:
			{
				gchar* _tmp14_;
				_tmp14_ = g_strdup (_ ("Nintendo GameCube"));
				result = _tmp14_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label11) ? _tmp2_label11 : (_tmp2_label11 = g_quark_from_static_string ("GameGear")))) {
		switch (0) {
			default:
			{
				gchar* _tmp15_;
				_tmp15_ = g_strdup (_ ("Game Gear"));
				result = _tmp15_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label12) ? _tmp2_label12 : (_tmp2_label12 = g_quark_from_static_string ("MAME")))) {
		switch (0) {
			default:
			{
				gchar* _tmp16_;
				_tmp16_ = g_strdup (_ ("MAME"));
				result = _tmp16_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label13) ? _tmp2_label13 : (_tmp2_label13 = g_quark_from_static_string ("NeoGeoPocket")))) {
		switch (0) {
			default:
			{
				gchar* _tmp17_;
				_tmp17_ = g_strdup (_ ("Neo Geo Pocket"));
				result = _tmp17_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label14) ? _tmp2_label14 : (_tmp2_label14 = g_quark_from_static_string ("NintendoEntertainmentSystem")))) {
		switch (0) {
			default:
			{
				gchar* _tmp18_;
				_tmp18_ = g_strdup (_ ("Nintendo Entertainment System"));
				result = _tmp18_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label15) ? _tmp2_label15 : (_tmp2_label15 = g_quark_from_static_string ("Nintendo64")))) {
		switch (0) {
			default:
			{
				gchar* _tmp19_;
				_tmp19_ = g_strdup (_ ("Nintendo 64"));
				result = _tmp19_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label16) ? _tmp2_label16 : (_tmp2_label16 = g_quark_from_static_string ("NintendoDS")))) {
		switch (0) {
			default:
			{
				gchar* _tmp20_;
				_tmp20_ = g_strdup (_ ("Nintendo DS"));
				result = _tmp20_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label17) ? _tmp2_label17 : (_tmp2_label17 = g_quark_from_static_string ("Nintendo3DS")))) {
		switch (0) {
			default:
			{
				gchar* _tmp21_;
				_tmp21_ = g_strdup (_ ("Nintendo 3DS"));
				result = _tmp21_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label18) ? _tmp2_label18 : (_tmp2_label18 = g_quark_from_static_string ("PlayStation")))) {
		switch (0) {
			default:
			{
				gchar* _tmp22_;
				_tmp22_ = g_strdup (_ ("PlayStation"));
				result = _tmp22_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label19) ? _tmp2_label19 : (_tmp2_label19 = g_quark_from_static_string ("PlayStation2")))) {
		switch (0) {
			default:
			{
				gchar* _tmp23_;
				_tmp23_ = g_strdup (_ ("PlayStation 2"));
				result = _tmp23_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label20) ? _tmp2_label20 : (_tmp2_label20 = g_quark_from_static_string ("PlayStation3")))) {
		switch (0) {
			default:
			{
				gchar* _tmp24_;
				_tmp24_ = g_strdup (_ ("PlayStation 3"));
				result = _tmp24_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label21) ? _tmp2_label21 : (_tmp2_label21 = g_quark_from_static_string ("PlayStation4")))) {
		switch (0) {
			default:
			{
				gchar* _tmp25_;
				_tmp25_ = g_strdup (_ ("PlayStation 4"));
				result = _tmp25_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label22) ? _tmp2_label22 : (_tmp2_label22 = g_quark_from_static_string ("PlayStationPortable")))) {
		switch (0) {
			default:
			{
				gchar* _tmp26_;
				_tmp26_ = g_strdup (_ ("PlayStation Portable"));
				result = _tmp26_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label23) ? _tmp2_label23 : (_tmp2_label23 = g_quark_from_static_string ("PlayStationVita")))) {
		switch (0) {
			default:
			{
				gchar* _tmp27_;
				_tmp27_ = g_strdup (_ ("PlayStation Vita"));
				result = _tmp27_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label24) ? _tmp2_label24 : (_tmp2_label24 = g_quark_from_static_string ("Sega32X")))) {
		switch (0) {
			default:
			{
				gchar* _tmp28_;
				_tmp28_ = g_strdup (_ ("Genesis 32X"));
				result = _tmp28_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label25) ? _tmp2_label25 : (_tmp2_label25 = g_quark_from_static_string ("SegaCD")))) {
		switch (0) {
			default:
			{
				gchar* _tmp29_;
				_tmp29_ = g_strdup (_ ("Sega CD"));
				result = _tmp29_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label26) ? _tmp2_label26 : (_tmp2_label26 = g_quark_from_static_string ("SegaCD32X")))) {
		switch (0) {
			default:
			{
				gchar* _tmp30_;
				_tmp30_ = g_strdup (_ ("Sega CD 32X"));
				result = _tmp30_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label27) ? _tmp2_label27 : (_tmp2_label27 = g_quark_from_static_string ("SegaGenesis")))) {
		switch (0) {
			default:
			{
				gchar* _tmp31_;
				_tmp31_ = g_strdup (_ ("Sega Genesis"));
				result = _tmp31_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label28) ? _tmp2_label28 : (_tmp2_label28 = g_quark_from_static_string ("SegaMasterSystem")))) {
		switch (0) {
			default:
			{
				gchar* _tmp32_;
				_tmp32_ = g_strdup (_ ("Sega Master System"));
				result = _tmp32_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label29) ? _tmp2_label29 : (_tmp2_label29 = g_quark_from_static_string ("SegaPico")))) {
		switch (0) {
			default:
			{
				gchar* _tmp33_;
				_tmp33_ = g_strdup (_ ("Sega Pico"));
				result = _tmp33_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label30) ? _tmp2_label30 : (_tmp2_label30 = g_quark_from_static_string ("SegaSaturn")))) {
		switch (0) {
			default:
			{
				gchar* _tmp34_;
				_tmp34_ = g_strdup (_ ("Sega Saturn"));
				result = _tmp34_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label31) ? _tmp2_label31 : (_tmp2_label31 = g_quark_from_static_string ("SG1000")))) {
		switch (0) {
			default:
			{
				gchar* _tmp35_;
				_tmp35_ = g_strdup (_ ("SG-1000"));
				result = _tmp35_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label32) ? _tmp2_label32 : (_tmp2_label32 = g_quark_from_static_string ("SuperNintendoEntertainmentSystem")))) {
		switch (0) {
			default:
			{
				gchar* _tmp36_;
				_tmp36_ = g_strdup (_ ("Super Nintendo Entertainment System"));
				result = _tmp36_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label33) ? _tmp2_label33 : (_tmp2_label33 = g_quark_from_static_string ("TurboGrafx16")))) {
		switch (0) {
			default:
			{
				gchar* _tmp37_;
				_tmp37_ = g_strdup (_ ("TurboGrafx-16"));
				result = _tmp37_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label34) ? _tmp2_label34 : (_tmp2_label34 = g_quark_from_static_string ("TurboGrafxCD")))) {
		switch (0) {
			default:
			{
				gchar* _tmp38_;
				_tmp38_ = g_strdup (_ ("TurboGrafx-CD"));
				result = _tmp38_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label35) ? _tmp2_label35 : (_tmp2_label35 = g_quark_from_static_string ("Wii")))) {
		switch (0) {
			default:
			{
				gchar* _tmp39_;
				_tmp39_ = g_strdup (_ ("Wii"));
				result = _tmp39_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label36) ? _tmp2_label36 : (_tmp2_label36 = g_quark_from_static_string ("WiiU")))) {
		switch (0) {
			default:
			{
				gchar* _tmp40_;
				_tmp40_ = g_strdup (_ ("Wii U"));
				result = _tmp40_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label37) ? _tmp2_label37 : (_tmp2_label37 = g_quark_from_static_string ("WiiWare")))) {
		switch (0) {
			default:
			{
				gchar* _tmp41_;
				_tmp41_ = g_strdup (_ ("WiiWare"));
				result = _tmp41_;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				result = NULL;
				return result;
			}
		}
	}
}



