/* gamepad-input-type.c generated by valac 0.35.5, the Vala compiler
 * generated from gamepad-input-type.vala, do not modify */

/* This file is part of GNOME Games. License: GPLv3*/

#include <glib.h>
#include <glib-object.h>


#define GAMES_TYPE_GAMEPAD_INPUT_TYPE (games_gamepad_input_type_get_type ())

typedef enum  {
	GAMES_GAMEPAD_INPUT_TYPE_AXIS,
	GAMES_GAMEPAD_INPUT_TYPE_BUTTON,
	GAMES_GAMEPAD_INPUT_TYPE_INVALID
} GamesGamepadInputType;



GType games_gamepad_input_type_get_type (void) G_GNUC_CONST;


GType games_gamepad_input_type_get_type (void) {
	static volatile gsize games_gamepad_input_type_type_id__volatile = 0;
	if (g_once_init_enter (&games_gamepad_input_type_type_id__volatile)) {
		static const GEnumValue values[] = {{GAMES_GAMEPAD_INPUT_TYPE_AXIS, "GAMES_GAMEPAD_INPUT_TYPE_AXIS", "axis"}, {GAMES_GAMEPAD_INPUT_TYPE_BUTTON, "GAMES_GAMEPAD_INPUT_TYPE_BUTTON", "button"}, {GAMES_GAMEPAD_INPUT_TYPE_INVALID, "GAMES_GAMEPAD_INPUT_TYPE_INVALID", "invalid"}, {0, NULL, NULL}};
		GType games_gamepad_input_type_type_id;
		games_gamepad_input_type_type_id = g_enum_register_static ("GamesGamepadInputType", values);
		g_once_init_leave (&games_gamepad_input_type_type_id__volatile, games_gamepad_input_type_type_id);
	}
	return games_gamepad_input_type_type_id__volatile;
}



